<?php

class Betriebe extends CI_Controller {

	// Attribute, um die DB-Konfiguration und App-Konfiguration zwischenzuspeichern
	private $my_db = 'mysql';
	private $my_charset = 'utf-8';
	private $myconfig;
	private $myaccess;

	public function __construct() {
		parent::__construct();
		
		$this->load->helper('url');
		$this->load->model('betriebe_model');	

		$this->load->library('session');	
		
		// Binde die DB-Konfiguration ein
		require(APPPATH.'config/database.php');		
		$this->my_db = $active_group; // Welche DB?
		$this->my_charset = $db[$active_group]['char_set']; // Welcher Zeichensatz?	
		
		// Binde die SchildInfo-Konfiguration ein
		require(APPPATH.'config/schildinfo-config.php');		
		$this->myconfig = $config;
		$this->myaccess = $access;
    }



	/* ----------------------------------------------------------------------- */
	/*  Kernmethode stellt Bedingungen für jeden Fall zusammen                 */
	/* ----------------------------------------------------------------------- */
	
	
	/* Übersicht über alle Betriebe */
	public function index($param1='') {
		
		// ZUGRIFFSPRÜFUNG						
		
		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?
		
		// Ist der Zugriff generell freigeschaltet?
	    if ((!isset($this->myaccess)) || (!isset($this->myaccess['betriebe'])) || (!$this->myaccess['betriebe']===true)) { return; }		

	    // Ist im Benutzermodus der Betriebszugriff freigeschaltet?
		if ($this->myconfig['login']===true) {
			$username = $this->session->userdata('username');
			if ($this->myaccess[$username]['betriebe']===false) { return; }	
		}	

		// Sammle Daten
		$data['betriebe'] = $this->betriebe_model->getBetriebe();
		
		// Druckausgabe?
		$druck = false;
		if ($param1==='print') { $druck = true; }

		// Excel-Ausgabe?
		$excel = false;
		if ($param1==='excel')  { $excel = true; }			

		// Parameter für die spätere Darstellung
		$data['title'] = "Übersicht aller Betriebe"; // Titel der Seite
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = "betriebe"; // aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		$data['druck'] = $druck;
		$data['excelfilename'] = 'Betriebe';
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }
		
		if ($excel===TRUE) {
			$this->load->view('betriebe/list-betriebe-excel', $data);	
		}
		else {

			// Baue die Seite abschnittweise auf
			$this->load->view('templates/header', $data);
			if ($druck===false) {	
				$this->load->view('templates/navbar', $data);
			}
			$this->load->view('templates/title', $data);

			if (empty($data['betriebe'])) {
				$data['infomessage'] = "Keine Betriebe eingetragen!";
				$this->load->view('templates/info', $data);						
			}
			else {
				// Druck-Button
				if ($druck===false) {						
					$url = site_url("").'/betriebe/index';				
					$data['url'] = $url;
				
					$full_url = $url;
					$data['full_url'] = $full_url;
							
					$this->load->view('betriebe/switch', $data);		
				}			
				$this->load->view('betriebe/list-betriebe', $data);							
			}

			$this->load->view('templates/footer');

		}

	}
	
	
	
	/* Übersicht über alle Schüler eines Betriebs */
	public function schuelerBetrieb($param1='', $param2='') {

		// ZUGRIFFSPRUEFUNG		

		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?
		
		// Ist der Zugriff generell freigeschaltet?
	    if ((!isset($this->myaccess)) || (!isset($this->myaccess['betriebe'])) || (!$this->myaccess['betriebe']===true)) { return; }	

	    // Ist im Benutzermodus der Betriebszugriff freigeschaltet?
		if ($this->myconfig['login']===true) {
			$username = $this->session->userdata('username');
			if ($this->myaccess[$username]['betriebe']===false) { return; }	
		}	

		// Betriebs-ID
		$id = $param1;

		// Druckausgabe?
		$druck = false;
		if ($param2==='print') { $druck = true; }

		// Excel-Ausgabe?
		$excel = false;
		if ($param2==='excel')  { $excel = true; }					

		// Sammle Daten
		$data['schuelerBetrieb'] = $this->betriebe_model->getSchuelerByBetrieb($id, $this->my_db);
		$betrieb = $this->betriebe_model->getBetriebsname($id);
		$betriebsname = $betrieb->allgadrname1;
						
		// Parameter für die spätere Darstellung
		$data['title'] = "Schüler des Betriebs " . $betriebsname;

		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = "Betrieb"; // aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)				
		$data['druck'] = $druck;
		$data['excelfilename'] = 'Betriebsschüler';
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }
		
		if ($excel===TRUE) {
			$this->load->view('betriebe/list-schueler-betrieb-excel', $data);	
		}
		else {
			// Baue die Seite abschnittweise auf
			$this->load->view('templates/header', $data);
			if ($druck===false) { $this->load->view('templates/navbar', $data); }
			$this->load->view('templates/title', $data);

			if (empty($data['schuelerBetrieb'])) {
				$data['infomessage'] = "Keine Schüler für den Betrieb eingetragen!";
				$this->load->view('templates/info', $data);	
			}
			else {
				// Druck-Button
				if ($druck===false) {						
					$url = site_url("").'/betriebe/schuelerBetrieb/'.$id;				
					$data['url'] = $url;
				
					$full_url = $url;
					$data['full_url'] = $full_url;
							
					$this->load->view('betriebe/switch', $data);		
				}			
				$this->load->view('betriebe/list-schueler-betrieb', $data);							
			}

			$this->load->view('templates/footer');			
		}
	}
	

	
	// Hilfsmethode überprüft vor dem Ausführen eines Controllers, ob Zugriffsberechtigung besteht
	private function checkLogin() {
		
		// Login-Mechanismus nicht aktiviert? Zugriff erteilt!
		if ((!isset($this->myconfig)) || (!isset($this->myconfig['login'])) || ($this->myconfig['login']===false)) { 
			return true; 
		}		
		
		// Login-Mechanismus aktiv => Prüfe, ob gültige Session vorhanden ist
		if (!isset($this->session)) { return false; } // Session vorhanden?
		
		$array = $this->session->all_userdata();
		if (!isset($array)) { return false; } // Session-Daten vorhanden?
		if (!isset($array['logged_in'])) { return false; } // Session-Parameter vorhanden?
		if (!isset($array['username'])) { return false; } // Session-Parameter vorhanden?
		
		$logged = $array['logged_in'];
		if ($logged===false) { return false; } // Session-Parameter richtig besetzt?
		
		return true; // Alle Bedingungen erfüllt
	}
	
}

?>