<?php

class Klasse extends CI_Controller {

	// Attribute, um die DB-Konfiguration und App-Konfiguration zwischenzuspeichern
	private $my_db = 'mysql';
	private $my_charset = 'utf-8';
	private $myconfig;
	private $myaccess;

	private $VERSION = "3.4";

	public function __construct() {
		parent::__construct();
		
		$this->load->helper('url');
		$this->load->model('klasse_model');	
		$this->load->model('schule_model');	

		$this->load->library('session');
		
		// Binde die DB-Konfiguration ein
		require(APPPATH.'config/database.php');		
		$this->my_db = $active_group; // Welche DB?
		$this->my_charset = $db[$active_group]['char_set']; // Welcher Zeichensatz?	
		
		// Binde die SchildInfo-Konfiguration ein
		require(APPPATH.'config/schildinfo-config.php');		
		$this->myconfig = $config;
		$this->myaccess = $access;
    }


	/* Übersicht über alle Klassen, gruppiert nach Jahrgang, erweitert mit Klassenstärken */
	public function index($param1='') {
		
		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?

		$druck = false;
		if ($param1==='print') { $druck = true; }
		
		// Sammle Daten
		$data['klassen'] = $this->klasse_model->getKlassen();
		$data['jahrgaenge'] = $this->klasse_model->getJahrgaenge();
		$data['klstaerken'] = $this->klasse_model->getKlassenstaerken();
		$data['jgstaerken'] = $this->klasse_model->getJahrgangsstaerken();

		$dieklassen = $this->klasse_model->getKlassenAnzahl();
		$data['titlecount'] = count($dieklassen);
		$dieschueler = $this->klasse_model->getSchuelerAnzahl();
		$data['titlecount2'] = count($dieschueler);

		// Parameter für die spätere Darstellung
		$data['title'] = "Klassen"; // Titel der Seite
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = "klassen"; // aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		$data['druck'] = false;
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		$data['version'] = $this->VERSION;
		$data['druck'] = $druck;

		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }
		
		// Baue die Seite abschnittweise auf
		$this->load->view('templates/header', $data);
		if ($druck===false) { // normaler Header
			$this->load->view('templates/navbar', $data);
		}
		$this->load->view('templates/title', $data);

		if (empty($data['klassen'])) {
			$data['infomessage'] = "Keine Klassen eingetragen!";
			$this->load->view('templates/info', $data);						
		}
		else {

			// Druck-Button
			if ($druck===false) {						
				$url = site_url("").'/klasse/index';				
				$data['url'] = $url;
			
				$full_url = $url;
				$data['full_url'] = $full_url;
						
				$this->load->view('klasse/switch', $data);	

				// Schuldaten für Unterschrift unter der Tabelle (bei Nicht-Druck)
				$data['schule'] = $this->schule_model->getSchuldaten();	
			}

			$this->load->view('klasse/list', $data);							
		}

		$this->load->view('templates/footer');

	}

	/* Übersicht über alle Klassen, für die Liste zum Excel-Export */
	public function export() {
		
		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?
		
		// Sammle Daten
		$data['klassen'] = $this->klasse_model->getKlassen();

		// Parameter für die Darstellung
		$data['title'] = "Klassenlisten (f&uuml;r den Export)"; // Titel der Seite
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = "extras"; // aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		$data['druck'] = false;
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }
		
		// Baue die Seite abschnittweise auf
		$this->load->view('templates/header', $data);
		$this->load->view('templates/navbar', $data);
		$this->load->view('templates/title', $data);

		$this->load->view('klasse/export', $data);						

		$this->load->view('templates/footer');
	}
	
	
	// Hilfsmethode überprüft vor dem Ausführen eines Controllers, ob Zugriffsberechtigung besteht
	private function checkLogin() {
		
		// Login-Mechanismus nicht aktiviert? Zugriff erteilt!
		if ((!isset($this->myconfig)) || (!isset($this->myconfig['login'])) || ($this->myconfig['login']===false)) { 
			return true; 
		}		
		
		// Login-Mechanismus aktiv => Prüfe, ob gültige Session vorhanden ist
		if (!isset($this->session)) { return false; } // Session vorhanden?
		
		$array = $this->session->all_userdata();
		if (!isset($array)) { return false; } // Session-Daten vorhanden?
		if (!isset($array['logged_in'])) { return false; } // Session-Parameter vorhanden?
		if (!isset($array['username'])) { return false; } // Session-Parameter vorhanden?
		
		$logged = $array['logged_in'];
		if ($logged===false) { return false; } // Session-Parameter richtig besetzt?
		
		return true; // Alle Bedingungen erfüllt
	}
	
}

?>