<?php

class Konferenz extends CI_Controller {

	// Attribute, um die DB-Konfiguration und App-Konfiguration zwischenzuspeichern
	private $my_db = 'mysql';
	private $my_charset = 'utf-8';
	private $myconfig;
	private $myaccess;

	public function __construct() {
		parent::__construct();
		
		$this->load->helper('url');
		
		// Binde mehrere Models hier zusammen
		$this->load->model('klasse_model');		
		$this->load->model('schueler_model');		
		$this->load->model('schuelergruppe_model');	

		$this->load->library('session');	
		
		// Binde die DB-Konfiguration ein
		require(APPPATH.'config/database.php');		
		$this->my_db = $active_group; // Welche DB?
		$this->my_charset = $db[$active_group]['char_set']; // Welcher Zeichensatz?	
		
		// Binde die SchildInfo-Konfiguration ein
		require(APPPATH.'config/schildinfo-config.php');		
		$this->myconfig = $config;
		$this->myaccess = $access;
    }


	/* Liste aller Klassen und Jahrgänge für die Konferenzfolien */
	public function index() {
		$this->listKlassen("html");
	}

	/* Liste aller Klassen und Jahrgänge für den Konferenzfolien-Export */
	public function export() {
		$this->listKlassen("htmlexport");
	}

	/* Liste aller Klassen und Jahrgänge für den Konferenzfolien-Druck */
	public function druck() {
		$this->listKlassen("druck");
	}

	/* Interne Methode listet alle Klassen für den gewünschten Zweck auf. */
	private function listKlassen($modus) {
		
		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?

		// ZUGRIFFSPRÜFUNG						
		
		// Ist der Zugriff generell freigeschaltet?
	    if ((!isset($this->myaccess)) || (!isset($this->myaccess['schueler_noten'])) || (!$this->myaccess['schueler_noten']===true)) { return; }		

		// Ist der Zugriff im Benutzermodus freigeschaltet?
		if ($this->myconfig['login']===true) {
			$username = $this->session->userdata('username');
			if ($this->myaccess[$username]['schueler_noten']===false) { return; }
		}
		
		// Sammle Daten
		$data['klassen'] = $this->klasse_model->getKlassen();
		$data['jahrgaenge'] = $this->klasse_model->getJahrgaenge();

		// Parameter für die Darstellung
		$data['title'] = "Konferenzfolien"; // Titel der Seite
		if ($modus==="htmlexport") { $data['title'] = "Konferenzfolien (f&uuml;r den Export)"; }
		if ($modus==="druck") { $data['title'] = "Konferenzfolien (zum Ausdrucken)"; }
		$data['aktiv'] = "extras"; // aktiver Bereich
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		$data['druck'] = false;
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }
		
		// Baue Seite abschnittweise auf
		$this->load->view('templates/header', $data);
		$this->load->view('templates/navbar', $data);
		$this->load->view('templates/title', $data);

		if (empty($data['klassen'])) {
			$data['infomessage'] = "Keine Klassen eingetragen!";
			$this->load->view('templates/info', $data);						
		}
		else {
			if ($modus==="html"){
				$this->load->view('konferenz/list', $data);				
			}
			else if ($modus==="htmlexport"){
				$this->load->view('konferenz/export', $data);				
			}
			else if ($modus==="druck"){
				$this->load->view('konferenz/druck', $data);				
			}
		}

		$this->load->view('templates/footer');

	}


	/* Bereitet die Konferenzfolien für eine Klasse vor. */
	public function klasse($link, $druck="") {
		
		if (preg_match('/\.html$/',$link)>0) { // HTML-Folien-Export
			list($vorne,$dummy) = explode('.html',$link);
			list($dummy,$id) = explode('Klasse-',$vorne);
			$this->folien($id,'',true,false,false);
		}		
		else if ($druck==="print-sw") { // SW-Ausdruck
			$this->folien($link,'',false,true,false);
		}
		else if ($druck==="print-color") { // Farb-Ausdruck
			$this->folien($link,'',false,true,true);
		}
		else { // HTML-Folien Ansicht
			$this->folien($link,'',false,false,false);
		}
		
	}

	/* Bereitet die Konferenzfolien für einen Jahrgang vor. */
	public function jahrgang($link, $druck="") {
		
		if (preg_match('/\.html$/',$link)>0) { // HTML-Folien-Export
			list($vorne,$dummy) = explode('.html',$link);
			list($dummy,$id) = explode('Jahrgang-',$vorne);
			$this->folien('',$id,true,false,false);
		}		
		else if ($druck==="print-sw") { // SW-Ausdruck
			$this->folien('',$link,false,true,false);
		}
		else if ($druck==="print-color") { // Farb-Ausdruck
			$this->folien('',$link,false,true,true);
		}
		else { // HTML-Folien Ansicht
			$this->folien('',$link,false,false,false);
		}
		
	}

	/* Bereitet die Konferenzfolien für eine Klasse bzw. einen Jahrgang vor. */
	private function folien($klasse='', $jahrgang='', $export=false, $druck=false, $farbdruck=false) {
		
		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?

		// ZUGRIFFSPRÜFUNG						
		
		// Ist der Zugriff generell freigeschaltet?
	    if ((!isset($this->myaccess)) || (!isset($this->myaccess['schueler_noten'])) || (!$this->myaccess['schueler_noten']===true)) { return; }		

		// Ist der Zugriff im Benutzermodus freigeschaltet?
		if ($this->myconfig['login']===true) {
			$username = $this->session->userdata('username');
			if ($this->myaccess[$username]['schueler_noten']===false) { return; }
		}
		
		// 1. Hole die Liste aller Schüler der Klasse / des Jahrgangs
		if ($klasse!='') { // Klassenmodus
			$schuelerliste = $this->schuelergruppe_model->getAktiveSchuelerByKlasse($klasse);
			$data['title'] = "Konferenzfolien Klasse ".$klasse; // Titel der Seite		
		} 
		else { // Jahrgangsmodus
			$schuelerliste = $this->schuelergruppe_model->getAktiveSchuelerByASDJahrgang($jahrgang);
			$data['title'] = "Konferenzfolien Jahrgang ".$jahrgang; // Titel der Seite		
		}
		
		// Parameter für die Darstellung besetzen
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		if ($export===true) {
			$data['path'] = "";
			$data['basepath'] = "";	
		}
		
		$data['aktiv'] = "extras"; // aktiver Bereich
		$data['druck'] = false;		
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)
		
		// Druck?
		$data['druck'] = $druck;
		$data['farbdruck'] = $farbdruck;

		// Sonderfall: keine Daten gefunden
		if (empty($schuelerliste)) {
			$data['infomessage'] = "Die ermittelte Sch&uuml;lergruppe ist leer!";
			$data['config'] = $this->myconfig;
			$data['access'] = $this->myaccess;

			if ($this->myconfig['login']===true) {
				$data['username'] = $username;
			}

			$data['path'] = site_url(""); // Pfad inkl. index.php
			$data['basepath'] = base_url(""); // Basispfad ohne

			$data['druck'] = false;	// kein autom. Druck, da keine Schüler!

			$this->load->view('templates/header', $data);
			$this->load->view('templates/navbar', $data);
			$this->load->view('templates/title', $data);
			$this->load->view('templates/info', $data);						
			$this->load->view('templates/footer');
			return;
		}
								
		// 2. Stelle den HTML-Rahmen im Reveal-Framework dar (Header)				
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;

		$data['theme'] = 'simple';
		$data['transition'] = 'default';
		
		$this->load->view('konferenz/folien-header', $data);

		// 3. Erzeuge für jeden einzelnen Schüler eine separate Folie

		// Bestimme allgemeine Infos über die Abschnitte der Schule
		$infos = $this->schueler_model->getAbschnittInfos();
		$data['infos'] = $infos;
		$nr = 0;
			
		foreach ($schuelerliste as $schueler) {	
			
			$data['schueler'] = $schueler;	
			$id = $schueler['id'];
			$nr++;
			$data['nr'] = $nr;

			// Bestimme relevante Jahrgänge für den Schüler
			$jahrgang = $schueler['asdjahrgang'];
			$qualiphase = false;
			$versetzung = true;
			$jahrgaenge = array();
			array_push($jahrgaenge, $jahrgang);
			if ($jahrgang==='Q1') { array_push($jahrgaenge, "Q2"); $qualiphase = true; }
			if ($jahrgang==='Q2') { array_push($jahrgaenge, "Q1"); $qualiphase = true; }
			if ($jahrgang==='12') { array_push($jahrgaenge, "13"); $qualiphase = true; }
			if ($jahrgang==='13') { array_push($jahrgaenge, "12"); $qualiphase = true; }	
			$oberstufe = $qualiphase;
			if ($jahrgang==='EF' || $jahrgang==='11') { $oberstufe = true; }
			if (($qualiphase===true) || ($jahrgang==='05')) { // keine Versetzung in der 5 / in der Qualiphase
				$versetzung = false;
			}			
			if ($infos->schuljahrabschnitt!=$infos->anzahlabschnitte) { // Versetzung nur in letztem Abschnitt
				$versetzung = false;
			}
			$data['qualiphase'] = $qualiphase;
			$data['oberstufe'] = $oberstufe;
			$data['versetzung'] = $versetzung;
			
			// Bestimme Abschnitte, Fächer und Noten
			if (count($this->myconfig['konferenzfolien']['abschnitte_ignorieren'])>0) {
				$data['abschnitte'] = $this->schueler_model->getSchuelerAbschnitteByIDAndJahrgangAndAbschnitte($id, $jahrgaenge, $this->myconfig['konferenzfolien']['abschnitte_ignorieren']);		
			}
			else {
				$data['abschnitte'] = $this->schueler_model->getSchuelerAbschnitteByIDAndJahrgang($id, $jahrgaenge);		
			}
			
			$data['faecher'] = $this->schueler_model->getSchuelerFaecherByIDAndJahrgangAndFilter($id, $jahrgaenge, $this->my_db, $this->myconfig['konferenzfolien']['kursart_ignorieren'], $this->myconfig['konferenzfolien']['fach_ignorieren'], $this->myconfig['konferenzfolien']['entwertet_anzeigen']);
			
			$data['faechernoten'] = $this->schueler_model->getSchuelerNotenByIDAndJahrgang($id, $jahrgaenge, $this->my_db);
			$data['bemerkungen'] = $this->schueler_model->getBemerkungen($id, $this->my_db);

			if ($this->myconfig['konferenzfolien']['schuelerfotos']===true) {
					$data['round'] = $this->myconfig['konferenzfolien']['schuelerfotos_abgerundet'];
					$data['foto'] = $this->schuelergruppe_model->getFoto($id);
			}
						
			// Stelle Ergebnis (Notentabelle, Bemerkungen) dar
			$this->load->view('konferenz/noten', $data);			
			$this->load->view('konferenz/bemerkungen', $data);			
		}		

		// 4. Stelle den HTML-Rahmen dar (Footer)				
		$this->load->view('konferenz/folien-footer', $data);

	}



	/* ------------------------------------------------------ */
	/*  Statische Hilfsmethoden für den View                  */
	/* ------------------------------------------------------ */

	public static function formatiereDatum($datum) {
		if (($datum===null) || ($datum==='')) {
			return '-';
		}
		else {
			return substr($datum,8,2).'.'.substr($datum,5,2).'.'.substr($datum,0,4);			
		}
	}

	public static function formatiereKurzDatum($datum) {
		if (($datum===null) || ($datum==='')) {
			return '-';
		}
		else {
			return substr($datum,8,2).'.'.substr($datum,5,2).'.';			
		}
	}


	// Hilfsmethode überprüft vor dem Ausführen eines Controllers, ob Zugriffsberechtigung besteht
	private function checkLogin() {
		
		// Login-Mechanismus nicht aktiviert? Zugriff erteilt!
		if ((!isset($this->myconfig)) || (!isset($this->myconfig['login'])) || ($this->myconfig['login']===false)) { 
			return true; 
		}		
		
		// Login-Mechanismus aktiv => Prüfe, ob gültige Session vorhanden ist
		if (!isset($this->session)) { return false; } // Session vorhanden?
		
		$array = $this->session->all_userdata();
		if (!isset($array)) { return false; } // Session-Daten vorhanden?
		if (!isset($array['logged_in'])) { return false; } // Session-Parameter vorhanden?
		if (!isset($array['username'])) { return false; } // Session-Parameter vorhanden?
		
		$logged = $array['logged_in'];
		if ($logged===false) { return false; } // Session-Parameter richtig besetzt?
		
		return true; // Alle Bedingungen erfüllt
	}
	
}

?>