<?php

class Kurs extends CI_Controller {

	// Attribute, um die DB-Konfiguration und App-Konfiguration zwischenzuspeichern
	private $my_db = 'mysql';
	private $my_charset = 'utf-8';
	private $myconfig;
	private $myaccess;

	public function __construct() {
		parent::__construct();
		
		$this->load->helper('url');
		$this->load->model('kurs_model');	

		$this->load->library('session');	

		// Binde die DB-Konfiguration ein
		require(APPPATH.'config/database.php');		
		$this->my_db = $active_group; // Welche DB?
		$this->my_charset = $db[$active_group]['char_set']; // Welcher Zeichensatz?	
		
		// Binde die SchildInfo-Konfiguration ein
		require(APPPATH.'config/schildinfo-config.php');		
		$this->myconfig = $config;
		$this->myaccess = $access;
    }


	/* Ermittelt eine Aufstellung aller Kurse des angegebenen Anschnitts */
	public function index($jahrgang='', $abschnitt='') {

		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?

		// Sammle Daten...
		if (($jahrgang!='') && ($abschnitt!='')) { // ...für den gewünschten Abschnitt
			$data['jahrgaenge'] = $this->kurs_model->getJahrgaenge($jahrgang, $abschnitt);
			$data['kurse'] = $this->kurs_model->getKurse($jahrgang, $abschnitt, false);	
			$data['staerken'] = $this->kurs_model->getKursstaerken($jahrgang, $abschnitt,$this->my_db);	
			$data['title'] = "Kurse ".$jahrgang."/".($jahrgang+1).".".$abschnitt; // Titel der Seite		
		}
		else { // ...für den aktuellen Abschnitt
			$data['jahrgaenge'] = $this->kurs_model->getJahrgaengeAktuell();
			$data['kurse'] = $this->kurs_model->getKurseAktuell();	
			$data['staerken'] = $this->kurs_model->getKursstaerkenAktuell($this->my_db);	
			$data['title'] = "Kurse"; // Titel der Seite		
		}
		
		// ...über alle Abschnitte (zum optionalen Umschalten)
		$data['abschnitte'] = $this->kurs_model->getAbschnitte();
		$data['schule'] = $this->kurs_model->getSchuldaten();

		// Parameter für die Darstellung
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = "kurse"; // aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		$data['druck'] = false;
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }

		// Stelle Ergebnis abschnittweise dar
		$this->load->view('templates/header', $data);
		$this->load->view('templates/navbar', $data);

		$this->load->view('templates/title', $data);

		if (empty($data['kurse'])) {
			$data['infomessage'] = "Keine Kurse eingetragen!";
			$this->load->view('templates/info', $data);						
		}
		else {
			$this->load->view('kurs/list', $data);							
		}

		$this->load->view('templates/footer', $data);

	}

	/* Ermittelt eine Aufstellung aller Kurse des aktuellen Anschnitts für den Excel-Export */
	public function export() {

		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?

		// Sammle Daten
		$data['kurse'] = $this->kurs_model->getKurseAktuellOrderByLehrer();	
		
		// Parameter für die Darstellung
		$data['title'] = "Kurslisten (f&uuml;r den Export)"; // Titel der Seite				
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = "extras"; // aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		$data['druck'] = false;
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }

		// Stelle Ergebnis abschnittweise dar
		$this->load->view('templates/header', $data);
		$this->load->view('templates/navbar', $data);
		$this->load->view('templates/title', $data);

		$this->load->view('kurs/export', $data);							

		$this->load->view('templates/footer', $data);

	}


	// Hilfsmethode überprüft vor dem Ausführen eines Controllers, ob Zugriffsberechtigung besteht
	private function checkLogin() {
		
		// Login-Mechanismus nicht aktiviert? Zugriff erteilt!
		if ((!isset($this->myconfig)) || (!isset($this->myconfig['login'])) || ($this->myconfig['login']===false)) { 
			return true; 
		}		
		
		// Login-Mechanismus aktiv => Prüfe, ob gültige Session vorhanden ist
		if (!isset($this->session)) { return false; } // Session vorhanden?
		
		$array = $this->session->all_userdata();
		if (!isset($array)) { return false; } // Session-Daten vorhanden?
		if (!isset($array['logged_in'])) { return false; } // Session-Parameter vorhanden?
		if (!isset($array['username'])) { return false; } // Session-Parameter vorhanden?
		
		$logged = $array['logged_in'];
		if ($logged===false) { return false; } // Session-Parameter richtig besetzt?
		
		return true; // Alle Bedingungen erfüllt
	}

}

?>