<?php

class Lehrer extends CI_Controller {

	// Attribute, um die DB-Konfiguration und App-Konfiguration zwischenzuspeichern
	private $my_db = 'mysql';
	private $my_charset = 'utf-8';
	private $myconfig;
	private $myaccess;

	public function __construct() {
		parent::__construct();
		
		$this->load->helper('url');
		$this->load->model('lehrer_model');	

		$this->load->library('session');	

		// Binde die DB-Konfiguration ein
		require(APPPATH.'config/database.php');		
		$this->my_db = $active_group; // Welche DB?
		$this->my_charset = $db[$active_group]['char_set']; // Welcher Zeichensatz?	
		
		// Binde die SchildInfo-Konfiguration ein
		require(APPPATH.'config/schildinfo-config.php');		
		$this->myconfig = $config;
		$this->myaccess = $access;
    }


	/* Zeige das Suchformular für Lehrer */
	public function index() {

		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?

		// ZUGRIFFSPRÜFUNG						
		
		// Ist der Zugriff generell freigeschaltet?
	    if ((!isset($this->myaccess)) || (!isset($this->myaccess['lehrer'])) || (!$this->myaccess['lehrer']===true)) { return; }		

		// Ist der Zugriff im Benutzermodus freigeschaltet?
		if ($this->myconfig['login']===true) {
			$username = $this->session->userdata('username');
			if ($this->myaccess[$username]['lehrer']===false) { return; }
		}
		
		// Parameter für die Darstellung
		$data['title'] = "Lehrer"; // Titel der Seite
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = "lehrer"; // aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		$data['druck'] = false;
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }

		// Stelle Seite mit Suchformular abschnittweise dar
		$this->load->view('templates/header', $data);
		$this->load->view('templates/navbar', $data);
		$this->load->view('templates/title', $data);

		$this->load->view('lehrer/form', $data);

		$this->load->view('templates/footer', $data);
	}


	/* Bestimme und zeige alle passenden Lehrer; nutze die Suchparameter */
	public function search() {

		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?

		// ZUGRIFFSPRÜFUNG						
		
		// Ist der Zugriff generell freigeschaltet?
	    if ((!isset($this->myaccess)) || (!isset($this->myaccess['lehrer'])) || (!$this->myaccess['lehrer']===true)) { return; }		

		// Ist der Zugriff im Benutzermodus freigeschaltet?
		if ($this->myconfig['login']===true) {
			$username = $this->session->userdata('username');
			if ($this->myaccess[$username]['lehrer']===false) { return; }
		}
		
		// Lies alle Suchparameter aus, sammle im Array
		$param = array();
		$param['aktiv'] = $this->input->post('aktiv');
		$param['statistik'] = $this->input->post('statistik');
		$param['kuerzel'] = $this->input->post('kuerzel');
		$param['amt'] = $this->input->post('amt');
		$param['anrede'] = $this->input->post('anrede');
		$param['titel'] = $this->input->post('titel');
		$param['strasse'] = $this->input->post('strasse');
		$param['ort'] = $this->input->post('ort');
		$param['telefon'] = $this->input->post('telefon');
		$param['handy'] = $this->input->post('handy');
		$param['email'] = $this->input->post('email');
		$param['emaildienstlich'] = $this->input->post('emaildienstlich');
		$param['fotos'] = $this->input->post('fotos');

		// Druck?
		$format= $this->input->post('format');
		$data['druck'] = false;
		if ($format==='htmlprint') {
			$format = 'html';
			$data['druck'] = true;
		}
		
		// Sammle Daten, d.h. suche Lehrer
		$data['lehrer'] = $this->lehrer_model->searchLehrer($param);
		
		// Werden Faecher gewuenscht? Suche alle Lehrer-Faecher-Kombinationen
		$param['faecher'] = $this->input->post('faecher');
		if ($param['faecher']==='on') {
			$data['faecher'] = $this->lehrer_model->getLehrerFaecher();
		}

		if (($param['fotos']==='on') and ($format==='html')) {
			$data['allefotos'] = $this->lehrer_model->getLehrerFotos();
			$data['round'] = $this->myconfig['lehrerfotos_abgerundet'];
		}

		// Parameter für die Darstellung
		$data['title'] = "Lehrerliste"; // Titel der Seite
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = "lehrer"; // aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }

		// Nutze die Suchparameter auch zur Darstellung der Ergebnistabelle
		$data['param'] = $param;

		if ($format==='html') { // Format: HTML (mit/ohne Druck)
			$data['config'] = $this->myconfig;
			$data['access'] = $this->myaccess;

			// Setze Ergebnis abschnittweise zusammen
			$this->load->view('templates/header', $data);
			if ($data['druck']===false) { $this->load->view('templates/navbar', $data); }
			$this->load->view('templates/title', $data);		

			$this->load->view('lehrer/result', $data);				

			$this->load->view('templates/footer', $data);			
		}
		else if ($format==='dokuwiki') { // Format: DokuWiki
			$this->output->set_content_type("text/plain; charset=".$this->my_charset); // Textdatei
			$this->load->view('lehrer/wikiresult', $data);							
		}
		else if ($format==='yaml') { // Format: YAML
			$this->output->set_content_type("text/plain; charset=".$this->my_charset); // Textdatei
			$this->load->view('lehrer/yamlresult', $data);							
		}
		else if ($format==='excel') { // Format: Excel
			$this->output->set_content_type("application/vnd.ms-excel"); // Exceldatei
			$this->load->view('lehrer/excelresult', $data);		
		}
		else if ($format==='vcard2' or $format==='vcard3') { // Format: vCard
			$this->output->set_content_type("text/vcard; charset=".$this->my_charset); // Textdatei
			if ($format==='vcard3') {
				$data['version'] = 3;	
			}
			else {
				$data['version'] = 2;
			}
			$this->load->view('lehrer/vcardresult', $data);		
		}
	}


	// Hilfsmethode überprüft vor dem Ausführen eines Controllers, ob Zugriffsberechtigung besteht
	private function checkLogin() {
		
		// Login-Mechanismus nicht aktiviert? Zugriff erteilt!
		if ((!isset($this->myconfig)) || (!isset($this->myconfig['login'])) || ($this->myconfig['login']===false)) { 
			return true; 
		}		
		
		// Login-Mechanismus aktiv => Prüfe, ob gültige Session vorhanden ist
		if (!isset($this->session)) { return false; } // Session vorhanden?
		
		$array = $this->session->all_userdata();
		if (!isset($array)) { return false; } // Session-Daten vorhanden?
		if (!isset($array['logged_in'])) { return false; } // Session-Parameter vorhanden?
		if (!isset($array['username'])) { return false; } // Session-Parameter vorhanden?
		
		$logged = $array['logged_in'];
		if ($logged===false) { return false; } // Session-Parameter richtig besetzt?
		
		return true; // Alle Bedingungen erfüllt
	}

}

?>