<?php

class Schueler extends CI_Controller {

	// Attribute, um die DB-Konfiguration und App-Konfiguration zwischenzuspeichern
	private $my_db = 'mysql';
	private $my_charset = 'utf-8';
	private $myconfig;
	private $myaccess;

	public function __construct() {
		parent::__construct();
		
		$this->load->helper('url');
		$this->load->model('schueler_model');

		$this->load->library('session');

		// Binde die DB-Konfiguration ein
		require(APPPATH.'config/database.php');		
		$this->my_db = $active_group; // Welche DB?
		$this->my_charset = $db[$active_group]['char_set']; // Welcher Zeichensatz?	
		
		// Binde die SchildInfo-Konfiguration ein
		require(APPPATH.'config/schildinfo-config.php');		
		$this->myconfig = $config;
		$this->myaccess = $access;
    }


	/* Ermittle und stelle alle Daten zum übergebenen Schüler (und den optionalen Parametern) dar. */
	public function view($id, $param1='', $param2='') {

		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?
		
		// Notenmodus? Druckausgabe?
		$noten = false;
		if (($param1==='noten') || ($param2==='noten')) { $noten = true; }
		$aktuell = false;
		if (($param1==='aktuell') || ($param2==='aktuell')) { $aktuell = true; }
		$druck = false;
		if (($param1==='print') || ($param2==='print')) { $druck = true; }
		$farbdruck = false;
		if (($param1==='colorprint') || ($param2==='colorprint')) { $druck = true; $farbdruck = true; }

		// Hole Daten unabhängig vom Modus
		$schueler = $this->schueler_model->getSchuelerByID($id);
		$data['schueler'] = $schueler;
		$data['title'] = $data['schueler']->vorname . " " . $data['schueler']->name; // Titel der Seite		

		if ($noten===false) { // Individualdatenmodus

			if ($aktuell===true) { // Sammle Daten: Belegungen des akt. Halbjahres
				$data['belegungen'] = $this->schueler_model->getSchuelerNotenByIDAndAbschnitt($id, $this->my_db);		
			}
			else { // Sammle Daten: Individualdaten usw.
				if ((isset($this->myconfig['schuelerfotos'])) && ($this->myconfig['schuelerfotos']===true)) {
					$data['foto'] = $this->schueler_model->getSchuelerFotoByID($id);
					$data['round'] = $this->myconfig['schuelerfotos_abgerundet'];
				}
				
				$data['erzieher'] = $this->schueler_model->getSchuelerErzieherByID($id);
				$data['kontakte'] = $this->schueler_model->getSchuelerTelefonkontakteByID($id);
				$data['vermerke'] = $this->schueler_model->getSchuelerVermerkeByID($id);
				$data['aufnahme'] = $this->schueler_model->getSchuelerAufnahmeByID($id);
				$data['aufnahmeschule'] = $this->schueler_model->getSchuelerAufnahmeSchuleByID($id);
				$data['abschluesse'] = $this->schueler_model->getSchuelerAbschluesseByID($id);
				$data['abgang'] = $this->schueler_model->getSchuelerAbgangByID($id);
				$data['abgangschule'] = $this->schueler_model->getSchuelerAbgangSchuleByID($id);
				$data['externeschule'] = $this->schueler_model->getSchuelerExterneSchuleByID($id);

				$data['betriebe'] = $this->schueler_model->getSchuelerBetriebByID($id);
				$data['betriebeort'] = $this->schueler_model->getSchuelerBetriebOrtByID($id, $this->my_db);
				$data['betriebeplz'] = $this->schueler_model->getSchuelerBetriebPLZByID($id);

				$data['wdh']='';
				if (count($this->schueler_model->getSchuelerWiederholungByID($id))>0) {
					$data['wdh']='ja';
				}
			}
		}
		else { // Sammle Daten: Notentabelle
			$data['abschnitte'] = $this->schueler_model->getSchuelerAbschnitteByID($id);
			$data['faecher'] = $this->schueler_model->getSchuelerFaecherByID($id, $this->my_db, $this->myconfig['notentab_kursart_ignorieren'], $this->myconfig['notentab_fach_ignorieren']);
			$data['faechernoten'] = $this->schueler_model->getSchuelerNotenByID($id, $this->my_db);
			$data['infos'] = $this->schueler_model->getAbschnittInfos();
		}
		
		// Nur für aktive Schüler machen Belegungen des akt. Halbjahrs Sinn
		$belegungmoeglich = false;
		if ((($schueler->status+0)===2) || (($schueler->status+0)===6)) { $belegungmoeglich = true; }
		$data['belegungmoeglich'] = $belegungmoeglich; 

		// Noten machen für Neuaufnahmen/Warteliste keinen Sinn
		$notenmoeglich = true;
		if ((($schueler->status+0)===0) || (($schueler->status+0)===1)) { $notenmoeglich = false; }
		$data['notenmoeglich'] = $notenmoeglich; 
		
		// Parameter für die Darstellung
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = "schueler"; // aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)
		$data['noten'] = $noten;
		$data['aktuell'] = $aktuell;
		$data['druck'] = $druck;
		$data['farbdruck'] = $farbdruck;
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }

		// 1. Header
		$this->load->view('templates/header', $data);
		
		// 2. Navigationsleiste
		if ($druck===false) { // normaler Header
			$this->load->view('templates/navbar', $data);
		}			

		// 3. Titel der Seite
		$this->load->view('templates/title', $data);

		// 4. Inhalt
		
		// a) Buttonleiste zum Umschalten zwischen Individualdaten und Noten
		if ($druck===false) {						
			$url = site_url("").'/schueler/view/'.$id;				
			$data['url'] = $url;
		
			$full_url = $url;
			if ($noten===true) { $full_url = $full_url.'/noten'; }
			if ($aktuell===true) { $full_url = site_url("").'/schueler/view/'.$id."/aktuell"; }
			$data['full_url'] = $full_url;
					
			$this->load->view('schueler/switch', $data);								
		}
		
		// b) Ergebnistabelle
		if ($noten===true) { // Notenmodus
			
			// ZUGRIFFSPRÜFUNG						
			
			// Ist der Zugriff auf Noten generell freigeschaltet?
		    if ((!isset($this->myaccess)) || (!isset($this->myaccess['schueler_noten'])) || (!$this->myaccess['schueler_noten']===true)) { return; }
			
			// Ist im Benutzermodus der Notenzugriff freigeschaltet?
			if ($this->myconfig['login']===true) {
				$username = $this->session->userdata('username');
				if ($this->myaccess[$username]['schueler_noten']===false) { return; }	
			}
			
			$this->load->view('schueler/noten', $data);				
		}
		else { // Individualdatenmodus / Aktuelles Halbjahr
			if ($aktuell===true) {
				$this->load->view('schueler/belegungen', $data); // akt. Halbjahr				
			}
			else {
				$this->load->view('schueler/view', $data); // Individualdaten usw.								
			}
		}

		// 5. Footer
		$this->load->view('templates/footer');
	}
	
	
	
	/* ------------------------------------------------------ */
	/*  Statische Hilfsmethode für den View                   */
	/* ------------------------------------------------------ */

	public static function formatiereDatum($datum) {
		if (($datum===null) || ($datum==='')) {
			return '-';
		}
		else {
			return substr($datum,8,2).'.'.substr($datum,5,2).'.'.substr($datum,0,4);			
		}
	}

	public static function formatiereKurzDatum($datum) {
		if (($datum===null) || ($datum==='')) {
			return '-';
		}
		else {
			return substr($datum,8,2).'.'.substr($datum,5,2).'.';			
		}
	}

	// Hilfsmethode überprüft vor dem Ausführen eines Controllers, ob Zugriffsberechtigung besteht
	private function checkLogin() {
		
		// Login-Mechanismus nicht aktiviert? Zugriff erteilt!
		if ((!isset($this->myconfig)) || (!isset($this->myconfig['login'])) || ($this->myconfig['login']===false)) { 
			return true; 
		}		
		
		// Login-Mechanismus aktiv => Prüfe, ob gültige Session vorhanden ist
		if (!isset($this->session)) { return false; } // Session vorhanden?
		
		$array = $this->session->all_userdata();
		if (!isset($array)) { return false; } // Session-Daten vorhanden?
		if (!isset($array['logged_in'])) { return false; } // Session-Parameter vorhanden?
		if (!isset($array['username'])) { return false; } // Session-Parameter vorhanden?
		
		$logged = $array['logged_in'];
		if ($logged===false) { return false; } // Session-Parameter richtig besetzt?
		
		return true; // Alle Bedingungen erfüllt
	}
	
}

?>