<?php

class Schuelersearch extends CI_Controller {

	// Attribute, um die DB-Konfiguration und App-Konfiguration zwischenzuspeichern
	private $my_db = 'mysql';
	private $my_charset = 'utf-8';
	private $myconfig;
	private $myaccess;
		

	public function __construct() {
		parent::__construct();
		
		$this->load->helper('url');		
		$this->load->model('schuelersearch_model');

		$this->load->library('session');

		// Binde die DB-Konfiguration ein
		require(APPPATH.'config/database.php');		
		$this->my_db = $active_group; // Welche DB?
		$this->my_charset = $db[$active_group]['char_set']; // Welcher Zeichensatz?	

		// Binde die SchildInfo-Konfiguration ein
		require(APPPATH.'config/schildinfo-config.php');		
		$this->myconfig = $config;
		$this->myaccess = $access;
    }


	/* ------------------------------------------------------ */
	/*  Textsuche: Name, Vorname                              */
	/* ------------------------------------------------------ */

	/* Ermittle und stelle dar alle matchenden Schüler für freien Suchtext */
	public function name() {
		
		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?

		$query = '';
		$query = $this->input->post('query');
		
		// Parameter für die Darstellung
		$data['title'] = "Suchergebnis: \"".$query."\""; // Titel der Seite
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = "schueler"; // aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		$data['druck'] = false;
		$data['farbdruck'] = false;
		$data['modus'] = "search";
		$data['namen'] = false; // Setze Spezialmodi auf false, da View mit normaler Darstellung geteilt wird.
		$data['adressen'] = false;
		$data['noten'] = false;
		$data['abschnitte'] = false;
		$data['alterabschnitt'] = false;		
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }

		// Stelle Ergebnis abschnittweise dar
		$this->load->view('templates/header', $data);
		$this->load->view('templates/navbar', $data);
		$this->load->view('templates/title', $data);		

		if ($query==="") {
			$data['errormessage'] = "Suchtext leer!";
			$this->load->view('templates/error', $data);		
		}
		else { // Sammle Daten und stelle dar
			// Passt der Nachname?
			$data['schueler'] = $this->schuelersearch_model->getAktiveSchuelerByNachname($query, $this->my_db);
			$data['subtitle'] = 'Aktive Sch&uuml;ler mit passendem Nachnamen';
			
			if (empty($data['schueler'])) {
				$data['infomessage'] = "Kein passender Sch&uuml;ler gefunden!";
				$this->load->view('templates/info', $data);						
			}
			else {
				$this->load->view('schuelergruppe/list', $data);							
			}

			// Passt der Vorname?
			$data['schueler'] = $this->schuelersearch_model->getAktiveSchuelerByVorname($query, $this->my_db);
			$data['subtitle'] = 'Aktive Sch&uuml;ler mit passendem Vornamen';
			
			if (empty($data['schueler'])) {
				$data['infomessage'] = "Kein passender Sch&uuml;ler gefunden!";
				$this->load->view('templates/info', $data);						
			}
			else {
				$this->load->view('schuelergruppe/list', $data);							
			}
		}

		$this->load->view('templates/footer');
	}
	
	
	
	/* ------------------------------------------------------ */
	/*  Allgemeine Suche nach diversen Parametern             */
	/* ------------------------------------------------------ */	
	
	/* Zeige das Suchformular für Lehrer */
	public function index() {

		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?

		// Sammle Daten (alle Klassen, Jahrgänge, Kurse)
		$this->load->model('klasse_model');		
		$this->load->model('kurs_model');		
		
		$data['klassen'] = $this->klasse_model->getKlassen();
		$data['jahrgaenge'] = $this->klasse_model->getJahrgaenge();
		$data['kurse'] = $this->kurs_model->getKurseAktuell();			

		// Parameter für die Darstellung
		$data['title'] = "Sch&uuml;ler"; // Titel der Seite
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = "schueler"; // aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		$data['druck'] = false;
		$data['farbdruck'] = false;
		$data['modus'] = "search";
		$data['namen'] = false; // Setze Spezialmodi auf false, da View mit normaler Darstellung geteilt wird.
		$data['adressen'] = false;
		$data['noten'] = false;
		$data['abschnitte'] = false;
		$data['alterabschnitt'] = false;		
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }

		// Stelle Seite mit Suchformular abschnittweise dar
		$this->load->view('templates/header', $data);
		$this->load->view('templates/navbar', $data);
		$this->load->view('templates/title', $data);

		$this->load->view('schuelersearch/form', $data);

		$this->load->view('templates/footer', $data);
	}
	

	/* Ermittle und stelle dar alle matchenden Schüler für die allgemeine Suchanfrage */
	public function search() {
		
		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?

		// Lies alle Suchparameter aus, sammle im Array
		$param = array();
		$param['aktiv'] = $this->input->post('aktiv'); // Status
		$param['abgaenger'] = $this->input->post('abgaenger');
		$param['abschluss'] = $this->input->post('abschluss');
		$param['extern'] = $this->input->post('extern');
		$param['beurlaubt'] = $this->input->post('beurlaubt');
		$param['neuaufnahme'] = $this->input->post('neuaufnahme');
		$param['warteliste'] = $this->input->post('warteliste');

		$param['wahlklasse'] = $this->input->post('wahlklasse'); // Gruppe
		$param['wahljahrgang'] = $this->input->post('wahljahrgang');
		$param['wahlkurs'] = $this->input->post('wahlkurs');

		$param['klasse'] = $this->input->post('klasse'); // Felder
		$param['lehrer'] = $this->input->post('lehrer');
		$param['jahrgang'] = $this->input->post('jahrgang');
		$param['wdh'] = $this->input->post('wdh');
		$param['geschlecht'] = $this->input->post('geschlecht');
		$param['gebdatum'] = $this->input->post('gebdatum');
		
		$param['aufnahme'] = $this->input->post('aufnahme');
		$param['abgang'] = $this->input->post('abgang');
		$param['uebergang'] = $this->input->post('uebergang');
		
		$param['strasse'] = $this->input->post('strasse');
		$param['ort'] = $this->input->post('ort');
		$param['telefon'] = $this->input->post('telefon');
		$param['email'] = $this->input->post('email');

		$param['sortierung'] = $this->input->post('sortierung'); // Sortierung
		$param['absteigend'] = $this->input->post('absteigend');

		$param['format'] = $this->input->post('format'); // Sortierung
		
		$data['param'] = $param;

		// Sammle die Daten
		$data['schueler'] = $this->schuelersearch_model->searchSchueler($param, $this->my_db);		
		if (!empty($data['schueler'])) { $data['titlecount'] = count($data['schueler']); } // Anzahl der Datensätze

		// Abhängige Parameter für die Darstellung
		$data['druck'] = false;
		if ($param['format']==="htmlprint") {
			$data['druck'] = true;			
		}

		// Allgemeine Parameter für die Darstellung
		$data['title'] = "Sch&uuml;lerliste"; // Titel der Seite
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = "schueler"; // aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }

		if (empty($data['schueler'])) { // Suche erfolglos => unabhängig vom Ausgabeformat als HTML-Seite melden
			$data['infomessage'] = "Kein passender Sch&uuml;ler gefunden!"; // falls kein Match
			$this->load->view('templates/header', $data);
			$this->load->view('templates/navbar', $data);
			$this->load->view('templates/title', $data);		
			$this->load->view('templates/info', $data);					
			$this->load->view('templates/footer');			
		}
		else {
			if ($param['format']==="excel") { // Excel-Ausgabe
				$this->output->set_content_type("application/vnd.ms-excel"); // Exceldatei
				$this->load->view('schuelersearch/result-excel', $data);
			}
			else { // HTML-Ausgabe
				$this->load->view('templates/header', $data);
				if ($data['druck']===false) { $this->load->view('templates/navbar', $data); }
				$this->load->view('templates/title', $data);		

				$this->load->view('schuelersearch/result', $data);					
				
				$this->load->view('templates/footer');			
			}			
		}
		
	}

	
	/* ------------------------------------------------------ */
	/*  Statische Hilfsmethoden für den View                  */
	/* ------------------------------------------------------ */

	public static function formatiereDatum($datum) {
		if (($datum===null) || ($datum==='')) {
			return '-';
		}
		else {
			return substr($datum,8,2).'.'.substr($datum,5,2).'.'.substr($datum,0,4);			
		}
	}

	// Hilfsmethode überprüft vor dem Ausführen eines Controllers, ob Zugriffsberechtigung besteht
	private function checkLogin() {
		
		// Login-Mechanismus nicht aktiviert? Zugriff erteilt!
		if ((!isset($this->myconfig)) || (!isset($this->myconfig['login'])) || ($this->myconfig['login']===false)) { 
			return true; 
		}		
		
		// Login-Mechanismus aktiv => Prüfe, ob gültige Session vorhanden ist
		if (!isset($this->session)) { return false; } // Session vorhanden?
		
		$array = $this->session->all_userdata();
		if (!isset($array)) { return false; } // Session-Daten vorhanden?
		if (!isset($array['logged_in'])) { return false; } // Session-Parameter vorhanden?
		if (!isset($array['username'])) { return false; } // Session-Parameter vorhanden?
		
		$logged = $array['logged_in'];
		if ($logged===false) { return false; } // Session-Parameter richtig besetzt?
		
		return true; // Alle Bedingungen erfüllt
	}
	
}

?>