<?php

class Schule extends CI_Controller {

	// Attribute, um die DB-Konfiguration und App-Konfiguration zwischenzuspeichern
	private $my_db = 'mysql';
	private $my_charset = 'utf-8';
	private $myconfig;
	private $myaccess;

	private $VERSION = "3.4";

	public function __construct() {
		parent::__construct();
		
		$this->load->helper('url');
		$this->load->model('schule_model');

		$this->load->library('session');

		// Binde die DB-Konfiguration ein
		require(APPPATH.'config/database.php');		
		$this->my_db = $active_group; // Welche DB?
		$this->my_charset = $db[$active_group]['char_set']; // Welcher Zeichensatz?	
		
		// Binde die SchildInfo-Konfiguration ein
		require(APPPATH.'config/schildinfo-config.php');		
		$this->myconfig = $config;
		$this->myaccess = $access;
    }

	/* Erzeugt die Loginseite mit Informationen zur Schule (u.a. aktueller Abschnitt) */
	public function login() {		

		if ($this->myconfig['login']===false) { redirect('/klasse/index'); } // Benutzerlogin ausgeschaltet? Direkt zur Startseite!
			
		// Loginversuch? Daten prüfen!
		$username = $this->input->post('name');
		$userpwd = $this->input->post('kennwort');
		
		if ($username!='') { // Anmeldeversuch
			if (!isset($this->myaccess[$username])) { // Benutzer unbekannt
				$data['fehlermeldung'] = "Benutzername '$username' unbekannt!";				
			}		
			else {			
				$kennwort = $this->myaccess[$username]['kennwort'];
				if (!isset($kennwort)) { // Kennwort nicht gesetzt = Benutzer unbekannt
					$data['fehlermeldung'] = "Benutzername '$username' unbekannt!";				
				}
				else {
					if ( $userpwd===$kennwort) { // Anmeldung korrekt! => Setze Session-Objekt und leite auf Startseite weiter
						$newdata = array('username'  => $username, 'logged_in' => TRUE);
						$this->session->set_userdata($newdata);	
						redirect('/klasse/index');					
					}
					else { // Benutzer unbekannt => Meldung ausgeben
						$data['fehlermeldung'] = "Das Kennwort f&uuml;r den Benutzer '$username' ist leider falsch!";
					}				
				}
			}	
		}
		
		// Loginversuch gescheitert ODER erster Zugriff auf Loginseite 
		
		// Sammle Daten
		$data['schule'] = $this->schule_model->getSchuldaten();
		
		// Parameter für die Darstellung
		$data['title'] = "";
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = ""; // kein aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		$data['druck'] = false;
		$data['version'] = $this->VERSION;
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;

		// Stelle Seite abschnittweise dar
		$this->load->view('templates/header', $data);
		$this->load->view('templates/title', $data);

		$this->load->view('schule/login', $data);

		$this->load->view('templates/footer', $data);
	}
	
	
	/* Logout: Beende die Session und zeige die Login-Seite */
	public function logout() {
		$this->session->sess_destroy();		
		redirect('/schule/login');	
	}
	
	
	// Hilfsmethode überprüft vor dem Ausführen eines Controllers, ob Zugriffsberechtigung besteht
	private function checkLogin() {
		
		// Login-Mechanismus nicht aktiviert? Zugriff erteilt!
		if ((!isset($this->myconfig)) || (!isset($this->myconfig['login'])) || ($this->myconfig['login']===false)) { 
			return true; 
		}		
		
		// Login-Mechanismus aktiv => Prüfe, ob gültige Session vorhanden ist
		if (!isset($this->session)) { return false; } // Session vorhanden?
		
		$array = $this->session->all_userdata();
		if (!isset($array)) { return false; } // Session-Daten vorhanden?
		if (!isset($array['logged_in'])) { return false; } // Session-Parameter vorhanden?
		if (!isset($array['username'])) { return false; } // Session-Parameter vorhanden?
		
		$logged = $array['logged_in'];
		if ($logged===false) { return false; } // Session-Parameter richtig besetzt?
		
		return true; // Alle Bedingungen erfüllt
	}

	// Erzeugt die Startseite mit Informationen zur Schule (u.a. aktueller Abschnitt)
	public function indexalt() {		
		
		if ($this->checkLogin()===false) { redirect('/schule/login'); } // Login erforderlich und noch nicht erfolgt?
		
		// Sammle Daten
		$data['schule'] = $this->schule_model->getSchuldaten();
		
		// Parameter für die Darstellung
		$data['title'] = "";
		$data['path'] = site_url(""); // Pfad inkl. index.php
		$data['basepath'] = base_url(""); // Basispfad ohne index.php
		$data['aktiv'] = ""; // kein aktiver Bereich
		$data['charset'] = $this->my_charset; // Nutze den DB-Zeichensatz für die Ausgabe (sonst Darstellungsprobleme!)		
		$data['druck'] = false;
		$data['version'] = $this->VERSION;
		$data['config'] = $this->myconfig;
		$data['access'] = $this->myaccess;
		if ($this->myconfig['login']===true) { $data['username'] = $this->session->userdata('username'); }

		// Stelle Ergebnis abschnittweise dar
		$this->load->view('templates/header', $data);
		$this->load->view('templates/navbar', $data);
		$this->load->view('templates/title', $data);

		$this->load->view('schule/index', $data);

		$this->load->view('templates/footer', $data);
	}

	
}

?>