<?php

class Kurs_model extends CI_Model {


	public function __construct() {
		parent::__construct();
	    $this->load->database();		
	}


	/* Bestimme alle Kurse des aktuellen Abschnitts */
	public function getKurseAktuell() {
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt
		return $this->getKurse($schuljahr_aktuell, $abschnitt_aktuell, false);		
	}

	/* Bestimme alle Kurse des aktuellen Abschnitts, sortiert nach Lehrkräften */
	public function getKurseAktuellOrderByLehrer() {
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt
		return $this->getKurse($schuljahr_aktuell, $abschnitt_aktuell, true);		
	}

	/* Bestimme alle Kurse des angegebenen Abschnitts */
	public function getKurse($schuljahr, $abschnitt, $lehrersort) {
		$this->db->select('kurse.id, kurse.kurzbez, eigeneschule_faecher.zeugnisbez, kurse.lehrerkrz, kurse.asdjahrgang, kurse.kursartallg');
		$this->db->from('kurse');
		$this->db->join('eigeneSchule_faecher','kurse.fach_id=eigeneschule_faecher.id','inner');
		$this->db->where('kurse.jahr',$schuljahr+0); // erzwinge numerischen Datentyp
		$this->db->where('kurse.abschnitt',$abschnitt+0); // erzwinge numerischen Datentyp
		
		if ($lehrersort===true) {
			$this->db->order_by('kurse.lehrerkrz','asc');			
		}
		$this->db->order_by('kurse.asdjahrgang','asc');
		$this->db->order_by('kurse.kurzbez','asc');

		$query = $this->db->get();					
		return $query->result_array();		
	}

	/* Bestimme die Kursstärken der Kurse des aktuellen Abschnitts aus den Schülerbelegungen */
	public function getKursstaerkenAktuell($my_db) {
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt
		return $this->getKursstaerken($schuljahr_aktuell, $abschnitt_aktuell, $my_db, true);		
	}

	/* Bestimme die Kursstärken der Kurse des angegebenen Abschnitts aus den Schülerbelegungen */
	public function getKursstaerken($schuljahr, $abschnitt, $my_db, $aktuell=false) {
		$this->db->select('kurse.id, COUNT(*) as anzahl');
		
	 	$this->db->from('kurse');
		$this->db->join('schuelerleistungsdaten','kurse.id=schuelerleistungsdaten.kurs_id','inner'); // INNER JOIN
		$this->db->join('schuelerlernabschnittsdaten','schuelerleistungsdaten.abschnitt_id=schuelerlernabschnittsdaten.id','inner');
		$this->db->join('schueler','schueler.id=schuelerlernabschnittsdaten.schueler_id','inner');

	 	$this->db->where('geloescht','-');		
		if ($aktuell===true) { // im aktuellen Abschnitt nur Aktive und Externe anzeigen, sonst auch Ehemalige usw.
			$this->db->where_in('status',array(2,6));			
		}

		$this->db->where('kurse.jahr',$schuljahr+0); // erzwinge numerischen Datentyp
		$this->db->where('kurse.abschnitt',$abschnitt+0); // erzwinge numerischen Datentyp

		$this->db->group_by('kurse.id');
		$this->db->order_by('kurse.id','asc');
  		                    
		$query = $this->db->get();					
		return $query->result_array();		
	}

	/* Bestimme die Jahrgänge aller Kurse des aktuellen Abschnitts zur späteren Gruppierung */
	public function getJahrgaengeAktuell() {
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt
		return $this->getJahrgaenge($schuljahr_aktuell, $abschnitt_aktuell);		
	}

	/* Bestimme die Jahrgänge aller Kurse des angegebenen Abschnitts zur späteren Gruppierung */
	public function getJahrgaenge($schuljahr, $abschnitt) {
		$this->db->select('kurse.asdjahrgang');
		$this->db->from('kurse');

		$this->db->where('kurse.jahr',$schuljahr+0); // erzwinge numerischen Datentyp
		$this->db->where('kurse.abschnitt',$abschnitt+0); // erzwinge numerischen Datentyp
		
		// ASDJahrgang weder NULL noch leer - Lösung kompatibel mit Access und MySQL
		$this->db->where('(kurse.asdjahrgang IS NOT NULL)');
		$this->db->where("(NOT(Kurse.asdjahrgang=''))");
		
		$this->db->order_by('Kurse.asdjahrgang');
		$this->db->distinct();
		
		$query = $this->db->get();					
		return $query->result_array();		
	}

	/* Hilfsmethode ermittelt den aktuellen Abschnitt */
	private function getAbschnitt() {
		$this->db->select('schuljahr, schuljahrabschnitt');
		$this->db->from('eigeneschule');

		$query = $this->db->get();					
		$row = $query->row(); 
		
		return array($row->schuljahr, $row->schuljahrabschnitt);
	}

	/* Holt einige Infos über die Schule ein */
	public function getSchuldaten() {
	 	$this->db->select('bezeichnung1, schuljahr, schuljahrabschnitt, anzahlabschnitte, abschnittbez');
	 	$this->db->from('eigeneschule');
		
	 	$query = $this->db->get();			
		return $query->row(); // max. die erste Zeile		
	}

	/* Ermittelt alle hinterlegten Abschnitte */
	public function getAbschnitte() {
		$this->db->select('jahr, abschnitt');
		$this->db->from('kurse');
		
		$this->db->group_by('jahr');
		$this->db->group_by('abschnitt');
		
		$this->db->order_by('jahr','desc');
		$this->db->order_by('abschnitt','desc');
  		                    
		$query = $this->db->get();					
		return $query->result_array();		
	}
	
}

?>