<?php

class Schueler_model extends CI_Model {


	public function __construct() {
		parent::__construct();
	    $this->load->database();
		
	}
	

	/* ------------------------------------------------------ */
	/*  Individualdaten - Anfragen                            */
	/* ------------------------------------------------------ */

	/* Ermittelt alle verfügbare Daten zum Schüler mit der angegebenen ID */
	public function getSchuelerByID($id) {
		$this->db->select("id, name, vorname, klasse, asdjahrgang, strasse, plz, ortabk, telefon, email, geburtsdatum, geschlecht, externeschulnr, aufnahmedatum, entlassdatum, status, geburtsort, staatabk, religionabk, volljaehrig, aussiedler, keineauskunft, lehrer");

		$this->db->from('schueler');		
		$this->db->where('schueler.id',$id+0); // erzwinge numerischen Datentyp

		$query = $this->db->get();			
		return $query->row();
	}

	/* Liest das hinterlegte Foto zum Schüler mit der angegebenen ID */
	public function getSchuelerFotoByID($id) {
		$this->db->select("foto");

		$this->db->from('schuelerfotos');		
		$this->db->where('schueler_id',$id+0); // erzwinge numerischen Datentyp

		$query = $this->db->get();			
		return $query->row();
	}	

	/* Prüft eine evtl. aktuelle Wiederholung des Schüler mit der angegebenen ID */
	public function getSchuelerWiederholungByID($id) {
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt
		
		$this->db->select("schueler.id, schuelerlernabschnittsdaten.wiederholung");
		$this->db->from('schueler');		
		$this->db->join('schuelerlernabschnittsdaten','schueler.id=schuelerlernabschnittsdaten.schueler_id','inner'); // INNER JOIN

		$this->db->where('schueler.id',$id+0); // erzwinge numerischen Datentyp
		$this->db->where('schuelerlernabschnittsdaten.jahr',$schuljahr_aktuell+0); // erzwinge numerischen Datentyp
		$this->db->where('schuelerlernabschnittsdaten.abschnitt',$abschnitt_aktuell+0); // erzwinge numerischen Datentyp
		$this->db->where('schuelerlernabschnittsdaten.wiederholung','+');				
		$query = $this->db->get();			
		return $query->result_array();
	}
	
	/* Bestimmt alle Erzieherdatensaetze inkl. Adressen */
	public function getSchuelerErzieherByID($id) {
		$this->db->select('schuelererzadr.anrede1, schuelererzadr.titel1, schuelererzadr.vorname1, schuelererzadr.name1, schuelererzadr.anrede2, schuelererzadr.titel2, schuelererzadr.vorname2, schuelererzadr.name2, schuelererzadr.erzstrasse, schuelererzadr.erzplz, schuelererzadr.erzemail, k_ort.bezeichnung');
		$this->db->from('schuelererzadr');
		$this->db->join('k_ort','schuelererzadr.erzplz=k_ort.plz','inner'); // INNER JOIN
		$this->db->where('schuelererzadr.schueler_id',$id+0); // erzwinge numerischen Datentyp

		$query = $this->db->get();			
		return $query->result_array();
	}

	/* Bestimmt alle Telefonkontakt-Datensaetze */
	public function getSchuelerTelefonkontakteByID($id) {
		$this->db->select('k_telefonart.bezeichnung, schuelertelefone.telefonnummer');
		$this->db->from('schuelertelefone');
		$this->db->join('k_telefonart','schuelertelefone.telefonart_id=k_telefonart.id','inner'); // INNER JOIN
		$this->db->where('schuelertelefone.schueler_id',$id+0); // erzwinge numerischen Datentyp

		$query = $this->db->get();			
		return $query->result_array();
	}

	/* Bestimmt alle Vermerke des angegebenen Schülers */
	public function getSchuelerVermerkeByID($id) {
		$this->db->select('schuelervermerke.bemerkung, schuelervermerke.datum, k_vermerkart.bezeichnung');
		$this->db->from('schuelervermerke');
		$this->db->join('k_vermerkart','schuelervermerke.vermerkart_id=k_vermerkart.id','inner'); // INNER JOIN
		$this->db->where('schuelervermerke.schueler_id',$id+0); // erzwinge numerischen Datentyp
		$this->db->order_by('datum','desc');
			
		$query = $this->db->get();			
		return $query->result_array();
	}

	/* Bestimmt die Aufnahmedaten des angegebenen Schülers */
	public function getSchuelerAufnahmeByID($id) {
		$this->db->select('schueler.lsschulentlassdatum, schueler.lsentlassgrund, schueler.lsschulnr, schueler.aufnahmedatum, schueler.uebergangsempfehlung_jg5');
		$this->db->from('schueler');
		$this->db->where('schueler.id',$id+0); // erzwinge numerischen Datentyp
		
		$query = $this->db->get();			
		return $query->row();
	}

	/* Bestimmt die vorherige Schule des angegebenen Schülers */
	public function getSchuelerAufnahmeSchuleByID($id) {
		$this->db->select('k_schule.name');
		$this->db->from('schueler');
		$this->db->join('k_schule','schueler.lsschulnr=k_schule.schulnr','inner'); // INNER JOIN
		$this->db->where('schueler.id',$id+0); // erzwinge numerischen Datentyp
		
		$query = $this->db->get();			
		return $query->row();		
	}

	/* Bestimmt die evtl. Abgangsdaten des angegebenen Schülers */
	public function getSchuelerAbgangByID($id) {
		$this->db->select('schueler.entlassdatum, schueler.entlassgrund, schueler.schulwechselnr, schueler.schulwechseldatum');
		$this->db->from('schueler');
		$this->db->where('schueler.id',$id+0); // erzwinge numerischen Datentyp
		
		$query = $this->db->get();			
		return $query->row();
	}

	/* Bestimmt die evtl. Abgangsschule des angegebenen Schülers */
	public function getSchuelerAbgangSchuleByID($id) {
		$this->db->select('k_schule.name');
		$this->db->from('schueler');
		$this->db->join('k_schule','schueler.schulwechselnr=k_schule.schulnr','inner'); // INNER JOIN
		$this->db->where('schueler.id',$id+0); // erzwinge numerischen Datentyp
		
		$query = $this->db->get();			
		return $query->row();		
	}
	
	/* Bestimmt die erreichten Abschlüsse des angegebenen Schülers */
	public function getSchuelerAbschluesseByID($id) {
		$this->db->select('schuelerLernabschnittsdaten.abschluss, schuelerLernabschnittsdaten.jahr, schuelerlernabschnittsdaten.abschnitt');
		$this->db->from('schuelerlernabschnittsdaten');
		$this->db->where('schuelerlernabschnittsdaten.schueler_id',$id+0); // erzwinge numerischen Datentyp
		$this->db->where("(NOT(schuelerlernabschnittsdaten.abschluss=''))"); // Bedingung kompatibel mit Access und MySQL!
		$this->db->order_by('schuelerlernabschnittsdaten.jahr','desc');
		$this->db->order_by('schuelerlernabschnittsdaten.abschnitt','desc');
			
		$query = $this->db->get();			
		return $query->result_array();
	}

	/* Bestimmt die evtl. externe Schule des angegebenen Schülers */
	public function getSchuelerExterneSchuleByID($id) {
		$this->db->select('k_schule.name, k_schule.kurzbez');
		$this->db->from('schueler');
		$this->db->join('k_schule','schueler.externeschulnr=k_schule.schulnr','inner'); // INNER JOIN
		$this->db->where('schueler.id',$id+0); // erzwinge numerischen Datentyp
		
		$query = $this->db->get();			
		return $query->row();		
	}

	/* Bestimmt den Ausbildungsbetrieb des angegebenen Schülers */
	public function getSchuelerBetriebByID($id) {
		$this->db->select('k_allgadresse.AllgAdrName1');
		$this->db->from('schueler_allgadr');
		$this->db->join('k_allgadresse','schueler_allgadr.Adresse_ID=k_allgadresse.ID','inner'); // INNER JOIN
		$this->db->where('schueler_allgadr.schueler_id',$id+0); // erzwinge numerischen Datentyp
		$query = $this->db->get();			
		return $query->row();		
	}

	/* Bestimmt den Ausbildungsorts des angegebenen Schülers */
	public function getSchuelerBetriebPLZByID($id) {
		$this->db->select('k_allgadresse.AllgAdrPLZ');
		$this->db->from('schueler_allgadr');
		$this->db->join('k_allgadresse','schueler_allgadr.Adresse_ID=k_allgadresse.ID','inner'); // INNER JOIN
		$this->db->where('schueler_allgadr.schueler_id',$id+0); // erzwinge numerischen Datentyp
		$query = $this->db->get();			
		return $query->row();		
	}		
	
	/* Bestimmt den Ausbildungsorts des angegebenen Schülers */
	public function getSchuelerBetriebOrtByID($id, $my_db){
		$this->db->select('k_allgadresse.ID,k_allgadresse.AllgAdrPLZ');	
		$this->db->select('k_ort.PLZ,k_ort.Bezeichnung');	

		$this->db->from('schueler_allgadr');
		$this->db->join('k_allgadresse','schueler_allgadr.Adresse_ID=k_allgadresse.ID','inner'); // INNER JOIN			
		$this->db->join('k_ort','k_allgadresse.AllgAdrPLZ=k_ort.PLZ','inner'); // INNER JOIN

		$this->db->where('schueler_allgadr.schueler_id',$id+0); // erzwinge numerischen Datentyp
		$query = $this->db->get();			
		return $query->row();		
	}	

	/* Hilfsmethode ermittelt den aktuellen Abschnitt */
	private function getAbschnitt() {
		$this->db->select('schuljahr, schuljahrabschnitt');
		$this->db->from('eigeneschule');

		$query = $this->db->get();					
		$row = $query->row(); 
		
		return array($row->schuljahr, $row->schuljahrabschnitt);
	}


	/* ------------------------------------------------------ */
	/*  Schüler-Notenübersicht (auch: akt. Halbjahr)          */
	/* ------------------------------------------------------ */

	/* Bestimmt alle an der Schule absolvierten Abschnitte des angegebenen Schülers */
	public function getSchuelerAbschnitteByID($id) {
		return $this->getSchuelerAbschnitte($id, array(), array());
	}

	/* Bestimmt die Abschnitte in den angegebenen Jahrgängen des angegebenen Schülers */
	public function getSchuelerAbschnitteByIDAndJahrgang($id, $jahrgaenge) {
		return $this->getSchuelerAbschnitte($id, $jahrgaenge, array());
	}

	/* Bestimmt die Abschnitte in den angegebenen Jahrgängen bei Einschränkung auf die angegebenen Abschnitte des angegebenen Schülers */
	public function getSchuelerAbschnitteByIDAndJahrgangAndAbschnitte($id, $jahrgaenge, $abschnitte) {
		return $this->getSchuelerAbschnitte($id, $jahrgaenge, $abschnitte);
	}

	/* Bestimmt die gewünschten Abschnitte des angegebenen Schülers */
	private function getSchuelerAbschnitte($id, $jahrgaenge, $abschnitte) {
		$this->db->select('abschnitt, jahr,	id, klasse, asdjahrgang, klassenlehrer, abschluss, abschlistprognose, wiederholung, semesterwertung, sumfehlstd, sumfehlstdu');
		$this->db->from('schuelerlernabschnittsdaten');
		$this->db->where('schueler_id',$id+0); // erzwinge numerischen Datentyp
		if (count($jahrgaenge)>0) {
			$this->db->where_in('asdjahrgang', $jahrgaenge);
		}
		if (count($abschnitte)>0) {
			$this->db->where_not_in('abschnitt', $abschnitte);
		}
		$this->db->order_by('jahr','asc');
		$this->db->order_by('abschnitt','asc');
		
		$query = $this->db->get();			
		return $query->result_array();
	}


	/* Bestimmt alle an der Schule belegten Fächer des angegebenen Schülers */
	public function getSchuelerFaecherByID($id, $my_db, $ignore=array(), $ignore2=array()) {
		return $this->getSchuelerFaecher($id, array(), $my_db, $ignore, $ignore2);
	}

	/* Bestimmt alle in den gewünschten Jahrgängen belegten Fächer des angegebenen Schülers */
	public function getSchuelerFaecherByIDAndJahrgang($id, $jahrgaenge, $my_db) {
		return $this->getSchuelerFaecher($id, $jahrgaenge, $my_db, array(), array());
	}

	/* Bestimmt alle in den gewünschten Jahrgängen belegten Fächer des angegebenen Schülers */
	public function getSchuelerFaecherByIDAndJahrgangAndFilter($id, $jahrgaenge, $my_db, $ignore=array(), $ignore2=array(), $entwertet_anzeigen=true) {
		return $this->getSchuelerFaecher($id, $jahrgaenge, $my_db, $ignore, $ignore2, $entwertet_anzeigen);
	}

	/* Bestimmt alle belegten Fächer des angegebenen Schülers */
	private function getSchuelerFaecher($id, $jahrgaenge, $my_db, $ignore=array(), $ignore2=array(), $entwertet_anzeigen=true) {

		$this->db->select('eigeneSchule_faecher.fachkrz');
		
	 	$this->db->from('schueler');
		$this->db->join('schuelerlernabschnittsdaten','schueler.id=schuelerlernabschnittsdaten.schueler_id','inner');		
		$this->db->join('schuelerleistungsdaten','schuelerleistungsdaten.abschnitt_id=schuelerlernabschnittsdaten.id','inner');				
		$this->db->join('eigeneschule_faecher','schuelerleistungsdaten.fach_id=eigeneschule_faecher.id','inner');
		
		$this->db->where('schueler.id',$id+0); // erzwinge numerischen Datentyp
		if (count($jahrgaenge)>0) {
			$this->db->where_in('schuelerlernabschnittsdaten.asdjahrgang', $jahrgaenge);
		}
		
		if (count($ignore)>0) { // Ignoriere evtl. Kursarten aus Übersichtsgründen (vgl. Konfigurationsdatei)
			$and = "";
			$i = 0;
			foreach ($ignore as $ignore_item) {
				$and = $and . "(NOT(schuelerleistungsdaten.kursart='".$ignore_item."'))";
				$i = $i + 1;
				if ($i<count($ignore)) { $and = $and . " AND "; }
			}
			$this->db->where("((schuelerleistungsdaten.kursart IS NULL) OR (".$and."))");
		}

		if (count($ignore2)>0) { // Ignoriere evtl. Fächer aus Übersichtsgründen (vgl. Konfigurationsdatei)
			$and = "";
			$i = 0;
			foreach ($ignore2 as $ignore_item) {
				$and = $and . "(NOT(eigeneschule_faecher.fachkrz='".$ignore_item."'))";
				$i = $i + 1;
				if ($i<count($ignore2)) { $and = $and . " AND "; }
			}
			$this->db->where("((eigeneschule_faecher.fachkrz IS NULL) OR (".$and."))");
		}

		if ($entwertet_anzeigen==false) {
			$this->db->where("(schuelerlernabschnittsdaten.semesterwertung='+')");
		}

		$this->db->group_by('eigeneschule_faecher.fachkrz, eigeneschule_faecher.sortierung'); // Access erlaubt kein DISTINCT+ORDERBY, deshalb hier GRUPPIERUNG
		
		$this->db->order_by('eigeneschule_faecher.sortierung','asc');

		$query = $this->db->get();			
		return $query->result_array();
	}


	/* Bestimmt alle an der Schule erzielten Noten des angegebenen Schülers */
	public function getSchuelerNotenByID($id, $my_db) {
		return $this->getSchuelerNoten($id, array(), 0, 0, $my_db);
	}

	/* Bestimmt alle in den angegebenen Jahrgängen erzielten Noten des angegebenen Schülers */
	public function getSchuelerNotenByIDAndJahrgang($id, $jahrgaenge, $my_db) {
		return $this->getSchuelerNoten($id, $jahrgaenge, 0, 0, $my_db);
	}

	/* Bestimmt die im aktuellen Abschnitt erzielten Noten des angegebenen Schülers */
	public function getSchuelerNotenByIDAndAbschnitt($id, $my_db) {
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt		
		return $this->getSchuelerNoten($id, array(), $schuljahr_aktuell, $abschnitt_aktuell, $my_db);
	}
		
	/* Bestimmt alle an der Schule erzielten Noten des angegebenen Schülers */
	private function getSchuelerNoten($id, $jahrgaenge, $schuljahr, $abschnitt, $my_db) {		
		$this->db->select('schuelerleistungsdaten.fachlehrer, schuelerleistungsdaten.kursartallg, schuelerleistungsdaten.kurs_id, schuelerleistungsdaten.kursart, schuelerleistungsdaten.aufzeugnis, schuelerleistungsdaten.vorherabgeschl, eigeneschule_faecher.id, eigeneschule_faecher.fachkrz, schuelerleistungsdaten.notenkrz, schuelerleistungsdaten.warnung, schuelerleistungsdaten.warndatum, schuelerleistungsdaten.abschnitt_id, schuelerlernabschnittsdaten.asdjahrgang, schuelerlernabschnittsdaten.abschnitt, schuelerlernabschnittsdaten.jahr, schuelerleistungsdaten.fehlstd, schuelerleistungsdaten.ufehlstd');
		
	 	$this->db->from('schueler');
		$this->db->join('schuelerlernabschnittsdaten','schueler.id=schuelerlernabschnittsdaten.schueler_id','inner');		
		$this->db->join('schuelerleistungsdaten','schuelerleistungsdaten.abschnitt_id=schuelerlernabschnittsdaten.id','inner');				
		$this->db->join('eigeneschule_faecher','schuelerleistungsdaten.fach_id=eigeneschule_faecher.id','inner');
		
		$this->db->where('schueler.id',$id+0); // erzwinge numerischen Datentyp
		if (count($jahrgaenge)>0) {
			$this->db->where_in('schuelerlernabschnittsdaten.asdjahrgang', $jahrgaenge);
		}

		// Aktueller Abschnitt? WHERE-Bedingung und andere Sortierung
		if ($schuljahr>0) {
			$this->db->where('SchuelerLernabschnittsdaten.Jahr',$schuljahr+0); // erzwinge numerischen Datentyp
			$this->db->where('SchuelerLernabschnittsdaten.Abschnitt',$abschnitt+0);
			$this->db->order_by('eigeneschule_faecher.sortierung','asc');
		}
		else {
			$this->db->order_by('SchuelerLernabschnittsdaten.Jahr','asc');
			$this->db->order_by('SchuelerLernabschnittsdaten.Abschnitt','asc');			
		}

		$query = $this->db->get();			
		return $query->result_array();
	}

	// Ermittelt alle Bemerkungen (Engagement, ASV, allgemein) des angegbenen Schülers im aktuellen Abschnitt
	public function getBemerkungen($id, $my_db) {	
		
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt
		
		$this->db->select('asv, lels');
		
		$this->db->from('schueler');
		$this->db->join('schuelerlernabschnittsdaten','schueler.id=schuelerlernabschnittsdaten.schueler_id','inner'); // INNER JOIN
		$this->db->join('schuelerld_psfachbem','schuelerlernabschnittsdaten.id=schuelerld_psfachbem.abschnitt_id','inner'); // INNER JOIN
		
		$this->db->where('schueler.id',$id+0); // erzwinge numerischen Datentyp
		$this->db->where('schuelerlernabschnittsdaten.jahr',$schuljahr_aktuell+0); // erzwinge numerischen Datentyp
		$this->db->where('schuelerlernabschnittsdaten.abschnitt',$abschnitt_aktuell+0); // erzwinge numerischen Datentyp

		$query = $this->db->get();			
		return $query->row();
	}

	
	/* Hilfsmethode ermittelt Anzahl und Bezeichnung der Abschnitte */
	public function getAbschnittInfos() {
		$this->db->select('schuljahr, schuljahrabschnitt, anzahlabschnitte, abschnittbez');
		$this->db->from('eigeneschule');

		$query = $this->db->get();					
		return $query->row();
	}
	
}

?>