<?php

class Schuelergruppe_model extends CI_Model {

	// Attribute, die bei allen Anfragen projeziert werden
	private $attribute = "schueler.id, schueler.name, schueler.vorname, schueler.klasse, schueler.asdjahrgang, schueler.strasse, schueler.plz, schueler.ortabk, schueler.telefon, schueler.email, schueler.geburtsdatum, schueler.geschlecht, schueler.externeschulnr, schueler.aufnahmedatum, schueler.entlassdatum, schueler.status";


	public function __construct() {
		parent::__construct();
	    $this->load->database();
		
	}
	
	
	/* ------------------------------------------------------ */
	/*  Gruppen, die durch den Status zu filtern sind         */
	/* ------------------------------------------------------ */
	
	/* Ermittelt alle Schüler auf der Liste Neuaufnahmen durch ihren Status 0 */
	public function getNeuaufnahmenSchueler() {
		return $this->getSchuelerByStatus(0, 0);
	}

	/* Ermittelt alle Schüler auf der Warteliste durch ihren Status 1 */
	public function getWartelisteSchueler() {
		return $this->getSchuelerByStatus(1, 0);
	}

	/* Ermittelt alle beurlaubten Schüler durch ihren Status 3 */
	public function getBeurlaubteSchueler() {
		return $this->getSchuelerByStatus(3, 0);
	}

	/* Ermittelt alle externen Schüler durch ihren Status 6 */
	public function getExterneSchueler() {
		return $this->getSchuelerByStatus(6, 0);
	}

	/* Ermittelt alle Abgänger durch ihren Status 9 und ihr letztes Schuljahr = aktuelles Schuljahr an der Schule */
	public function getAbgaengerLaufend() {
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt
		
		return $this->getSchuelerByStatus(9,$schuljahr_aktuell+0);
	}

	/* Ermittelt alle Abgänger durch ihren Status 9 und ihr letztes Schuljahr = aktuelles Schuljahr - 1 an der Schule */
	public function getAbgaengerZuletzt() {
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt
		
		return $this->getSchuelerByStatus(9,$schuljahr_aktuell-1);
	}

	/* Ermittelt alle Abschluss-Schüler durch ihren Status 8 und ihr letztes Schuljahr = aktuelles Schuljahr - 1 an der Schule */
	public function getAbschluesseZuletzt() {
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt
		
		return $this->getSchuelerByStatus(8,$schuljahr_aktuell-1);
	}
	
	/* Hilfsmethode ermittelt alle Schüler mit dem übergebenen Status und ggf. dem übergebenen aktuellen Schuljahr */
	private function getSchuelerByStatus($status, $letztesschuljahr) {

		$this->db->select($this->attribute);
		if ($status===6) {
			$this->db->select('k_schule.kurzbez');
		}

		$this->db->from('schueler');				
		if ($status===6) {
			$this->db->join('k_schule','k_schule.schulnr=schueler.externeschulnr','inner');
		}		
		
		$this->db->where('schueler.geloescht','-');
		$this->db->where('schueler.status',$status);
		if ($letztesschuljahr>0) {
			$this->db->where('schueler.aktschuljahr',$letztesschuljahr+0); // erzwinge (vorsorglich) numerischen Datentyp
		}

		if (($status===1) || ($status===0)) { // Sortierung Warteliste, Neuaufnahmen
			$this->db->order_by('schueler.klasse','asc');
		}
		if ($status===6) { // Sortierung Externe
			$this->db->order_by('k_schule.kurzbez','asc');
			$this->db->order_by('schueler.asdjahrgang','asc');
		}
		if (($status===8) || ($status===9)) { // Sortierung Abgänger,Abschlüsse
			$this->db->order_by('schueler.entlassdatum','desc');
		}
		if ($letztesschuljahr!='') { // Sortierung Neuzugänge
			$this->db->order_by('schueler.klasse','asc');
		}
		$this->db->order_by('schueler.name','asc'); // allgemeine Sortierung
		$this->db->order_by('schueler.vorname','asc');

		$query = $this->db->get();			
		return $query->result_array();
	}
	


	/* ------------------------------------------------------ */
	/*  Individuelle Gruppen: Wiederholer, Neuaufnahmen       */
	/* ------------------------------------------------------ */

	/* Ermittelt alle aktiven Wiederholer des aktuellen Abschnitts */
	public function getWiederholer() {	
		
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt
		
		$this->db->select($this->attribute);
		$this->db->from('schueler');
		$this->db->join('schuelerlernabschnittsdaten','schueler.id=schuelerlernabschnittsdaten.schueler_id','inner'); // INNER JOIN
		$this->db->where('schueler.geloescht','-');
		$this->db->where('schueler.status',2);
		$this->db->where('schuelerlernabschnittsdaten.jahr',$schuljahr_aktuell+0); // erzwinge numerischen Datentyp
		$this->db->where('schuelerlernabschnittsdaten.abschnitt',$abschnitt_aktuell+0); // erzwinge numerischen Datentyp
		$this->db->where('schuelerlernabschnittsdaten.wiederholung','+');		
		$this->db->order_by('schueler.klasse','asc');
		$this->db->order_by('schueler.name','asc');
		$this->db->order_by('schueler.vorname','asc');

		$query = $this->db->get();			
		return $query->result_array();
	}


	/* Ermittelt alle Neuaufnahmen des aktuellen Schuljahres */
	public function getNeuaufnahmenLaufend() {	
		return $this->getNeuaufnahmenOffset(1);
	}
	
	/* Ermittelt alle Neuaufnahmen des aktuellen Schuljahres */
	public function getNeuaufnahmenZuletzt() {	
		return $this->getNeuaufnahmenOffset(0);
	}

	/* Hilfsmethode ermittelt alle Neuaufnahmen eines Schuljahres: $offset = 0 bzw. 1 bedeutet letztes bzw. aktuelles Schuljahr */
	private function getNeuaufnahmenOffset($offset) {	
		
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt

		$this->db->select($this->attribute);
		$this->db->from('schueler');
		
		// AND mit 4 Teilbedingungen
		$this->db->where('geloescht','-');
		$this->db->where('status',2);
		$this->db->where('year(aufnahmedatum)',$schuljahr_aktuell + $offset - 1);
		$this->db->where('month(aufnahmedatum) >=',8);
		
		// ODER zwischen den beiden Teilen (klappt, da UND stärker bindet als ODER)
		
		// AND mit 2 Teilbedingungen
		$this->db->or_where('year(aufnahmedatum)',$schuljahr_aktuell + $offset); // erzwinge numerischen Datentyp
		if ($offset===0) {
			$this->db->where('month(aufnahmedatum) <=',7);			
		}
		$this->db->where('geloescht','-');
		$this->db->where('status',2);

		$this->db->order_by('klasse','asc');
		$this->db->order_by('name','asc');
		$this->db->order_by('vorname','asc');

		$query = $this->db->get();			
		return $query->result_array();
	}


	/* ------------------------------------------------------ */
	/*  Aktive Schüler: alle, Klasse, Jahrgang                */
	/* ------------------------------------------------------ */

	/* Ermittelt alle aktiven Schüler */
	public function getAktiveSchueler() {
		return $this->getAktiveSchuelerByParameter('','');
	}
		
	/* Ermittelt alle aktiven Schüler der angegebenen Klasse */
	public function getAktiveSchuelerByKlasse($klasse) {
		return $this->getAktiveSchuelerByParameter($klasse,'');
	}

	/* Ermittelt alle aktiven Schüler des angegebenen Jahrgangs */
	public function getAktiveSchuelerByASDJahrgang($jahrgang) {
		return $this->getAktiveSchuelerByParameter('',$jahrgang);
	}
	
	/* Hilfsmethode ermittelt alle aktiven Schüler, ggf. selektiert duch einen Jg.-Kl.Parameter */
	private function getAktiveSchuelerByParameter($klasse, $jahrgang) {
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt
		return $this->getAktiveSchuelerByParameterAndAbschnitt($klasse, $jahrgang, $schuljahr_aktuell, $abschnitt_aktuell, '');
	}

	/* Ermittelt alle aktiven Schüler eines Abschnitts, ggf. selektiert duch einen Jg.-Kl.Parameter */
	public function getAktiveSchuelerByParameterAndAbschnitt($klasse, $jahrgang, $schuljahr, $abschnitt, $abschnittsklasse) {

		$this->db->select($this->attribute);
		$this->db->select('schuelerlernabschnittsdaten.wiederholung, schuelerlernabschnittsdaten.versetzungkrz, schuelerlernabschnittsdaten.moeglnpfaecher, schuelerlernabschnittsdaten.abschluss, schuelerlernabschnittsdaten.abschlistprognose, schuelerlernabschnittsdaten.abschlussart, schuelerlernabschnittsdaten.sumfehlstd, schuelerlernabschnittsdaten.sumfehlstdu, schuelerlernabschnittsdaten.zeugnisbem');

		$this->db->from('schueler');
		$this->db->join('schuelerlernabschnittsdaten','schueler.id=schuelerlernabschnittsdaten.schueler_id','inner');

		$this->db->where('geloescht','-');
		$this->db->where('status',2);
		
		if ($klasse!='') { $this->db->where('schueler.klasse',$klasse);	}
		if ($jahrgang!='') { $this->db->where('schueler.asdjahrgang',$jahrgang); }

		if ($abschnittsklasse!='') { // Suche eine alte Klasse
			$this->db->where('schuelerlernabschnittsdaten.klasse',$abschnittsklasse);	
		}

		$this->db->where('schuelerlernabschnittsdaten.jahr',$schuljahr+0); // erzwinge numerischen Datentyp
		$this->db->where('schuelerlernabschnittsdaten.abschnitt',$abschnitt+0); // erzwinge numerischen Datentyp

		$this->db->order_by('name','asc');
		$this->db->order_by('vorname','asc');

		$query = $this->db->get();			
		return $query->result_array();
	}


	/* ------------------------------------------------------ */
	/*  Besondere Ansicht: Klassennoten                       */
	/* ------------------------------------------------------ */


	/* Ermittelt alle Erzieher-Mailadressen für alle Schüler */
	public function getErzieherEmails() {
		$this->db->select('schueler.id, schuelererzadr.erzemail');
		$this->db->from('schuelererzadr');
		$this->db->join('schueler','schuelererzadr.schueler_id=schueler.id','inner'); // INNER JOIN
		
		$this->db->where('schuelererzadr.erzemail IS NOT NULL');

		$query = $this->db->get();			
		return $query->result_array();
	}

	/* Ermittelt alle Fotos für alle Schüler */
	public function getFotos() {
		$this->db->select('schueler_id, foto');
		$this->db->from('schuelerfotos');
		$this->db->where('foto IS NOT NULL');

		$query = $this->db->get();			
		return $query->result_array();
	}

	/* Ermittelt Foto für einen Schüler */
	public function getFoto($id) {
		$this->db->select('foto');
		$this->db->from('schuelerfotos');
		$this->db->where('schueler_id',$id+0);

		$query = $this->db->get();			
		return $query->row(); 
	}

	/* Ermittelt alle Betriebsadressen für alle Schüler */
	public function getBetriebeAdressen($my_db) {
		$this->db->select('k_allgadresse.id, k_allgadresse.allgadrplz, k_allgadresse.allgadrname1, schueler_allgadr.schueler_id');
		$this->db->select('k_ort.plz,k_ort.bezeichnung');	

		$this->db->from('schueler_allgadr');
		$this->db->join('k_allgadresse','schueler_allgadr.adresse_id=k_allgadresse.id','inner');
		$this->db->join('k_ort','k_allgadresse.allgadrplz=k_ort.plz','inner'); 

		$query = $this->db->get();								
		return $query->result_array();
	}	

	/* Ermittelt alle Fächer einer Klasse eines Abschnitts */
	public function getFaecherByKlasseAndAbschnitt($klasse, $schuljahr, $abschnitt, $abschnittsklasse, $oberstufe, $my_db, $ignore=array(), $ignore2=array()) {

		if ($oberstufe===false) { 
			$this->db->select('eigeneschule_faecher.fachkrz, schuelerleistungsdaten.fachlehrer, 
				schuelerleistungsdaten.kursartallg, 
				schuelerleistungsdaten.vorherabgeschl, 
				eigeneschule_faecher.sortierung');
		}
		else {
			$this->db->select('eigeneschule_faecher.fachkrz, eigeneschule_faecher.sortierung');
		}
	
	 	$this->db->from('schueler');
		$this->db->join('schuelerlernabschnittsdaten','schueler.id=schuelerlernabschnittsdaten.schueler_id','inner');		
		$this->db->join('schuelerleistungsdaten','schuelerleistungsdaten.abschnitt_id=schuelerlernabschnittsdaten.id','inner');				
		$this->db->join('eigeneschule_faecher','schuelerleistungsdaten.fach_id=eigeneschule_faecher.id','inner');	

		$this->db->where('geloescht','-');
		$this->db->where('status',2);

		if (count($ignore)>0) { // Ignoriere evtl. Fächer aus Übersichtsgründen (vgl. Konfigurationsdatei)
			$and = "";
			$i = 0;
			foreach ($ignore as $ignore_item) {
				$and = $and . "(NOT(schuelerleistungsdaten.kursart='".$ignore_item."'))";
				$i = $i + 1;
				if ($i<count($ignore)) { $and = $and . " AND "; }
			}
			$this->db->where("((schuelerleistungsdaten.kursart IS NULL) OR (".$and."))");
		}
				
		if (count($ignore2)>0) { // Ignoriere evtl. Fächer aus Übersichtsgründen (vgl. Konfigurationsdatei)
			$and = "";
			$i = 0;
			foreach ($ignore2 as $ignore_item) {
				$and = $and . "(NOT(eigeneschule_faecher.fachkrz='".$ignore_item."'))";
				$i = $i + 1;
				if ($i<count($ignore2)) { $and = $and . " AND "; }
			}
			$this->db->where("((eigeneschule_faecher.fachkrz IS NULL) OR (".$and."))");
		}

		$this->db->where('schuelerlernabschnittsdaten.klasse',$abschnittsklasse);	
		$this->db->where('schuelerlernabschnittsdaten.jahr',$schuljahr+0); // erzwinge numerischen Datentyp
		$this->db->where('schuelerlernabschnittsdaten.abschnitt',$abschnitt+0); // erzwinge numerischen Datentyp

		$this->db->where('schueler.klasse',$klasse);
		
		if ($oberstufe===false) { 
			$this->db->group_by('eigeneschule_faecher.fachkrz, schuelerleistungsdaten.fachlehrer, schuelerleistungsdaten.kursartallg, schuelerleistungsdaten.vorherabgeschl, eigeneschule_faecher.sortierung'); // Access erlaubt kein DISTINCT+ORDERBY, deshalb hier GRUPPIERUNG
			
		}
		else { // Fasse Fächer zusammen, da sonst zu viele Spalteninformationen
			$this->db->group_by('eigeneschule_faecher.fachkrz, eigeneschule_faecher.sortierung'); // Access erlaubt kein DISTINCT+ORDERBY, deshalb hier GRUPPIERUNG
			
		}

		$this->db->order_by('eigeneschule_faecher.sortierung','asc');
		if ($oberstufe===false) {
			$this->db->order_by('schuelerleistungsdaten.kursartallg','asc');
			$this->db->order_by('schuelerleistungsdaten.fachlehrer','asc');
			
		}

		$query = $this->db->get();			
		return $query->result_array();
	}
	
	/* Ermittelt alle Noten einer Klasse eines Abschnitts */
	public function getNotenByKlasseAndAbschnitt($klasse, $schuljahr, $abschnitt, $abschnittsklasse, $my_db) {

		$this->db->select('eigeneschule_faecher.fachkrz, schuelerleistungsdaten.notenkrz,  schuelerleistungsdaten.fachlehrer, schuelerleistungsdaten.aufzeugnis, schuelerleistungsdaten.warnung, schuelerleistungsdaten.warndatum, schuelerleistungsdaten.vorherabgeschl, schuelerleistungsdaten.kursartallg, schuelerleistungsdaten.kursart, schuelerleistungsdaten.fehlstd, schuelerleistungsdaten.ufehlstd, schuelerlernabschnittsdaten.asdjahrgang, schueler.id');

	 	$this->db->from('schueler');
		$this->db->join('schuelerlernabschnittsdaten','schueler.id=schuelerlernabschnittsdaten.schueler_id','inner');		
		$this->db->join('schuelerleistungsdaten','schuelerleistungsdaten.abschnitt_id=schuelerlernabschnittsdaten.id','inner');				
		$this->db->join('eigeneschule_faecher','schuelerleistungsdaten.fach_id=eigeneschule_faecher.id','inner');

		$this->db->where('geloescht','-');
		$this->db->where('status',2);
		
		$this->db->where('schuelerlernabschnittsdaten.klasse',$abschnittsklasse);	
		$this->db->where('schuelerlernabschnittsdaten.jahr',$schuljahr+0); // erzwinge numerischen Datentyp
		$this->db->where('schuelerlernabschnittsdaten.abschnitt',$abschnitt+0); // erzwinge numerischen Datentyp

		$this->db->where('schueler.klasse',$klasse);

		$query = $this->db->get();			
		return $query->result_array();
	}

	/* Ermittelt den ASD-Jahrgang zur Klasse */
	public function getJahrgangByKlasse($klasse) {
		$this->db->select('asdjahrgang');
		$this->db->from('versetzung');
		$this->db->join('eigeneschule_jahrgaenge', 'versetzung.jahrgang_id = eigeneschule_jahrgaenge.id','inner'); // INNER JOIN
		$this->db->where('klasse',$klasse);

		$query = $this->db->get();					
		$row = $query->row(); 
		return $row->asdjahrgang;		
	}
	
	/* Ermittle vorangegangene Abschnitte des aktuellen Abschnitts für die gewählte Klasse */
	public function getAbschnitteByKlasseBeforeNow($klasse, $schuljahr, $abschnitt) {
		$this->db->select('jahr, abschnitt');
		$this->db->from('schuelerlernabschnittsdaten');

		$this->db->where('klasse',$klasse);
		$this->db->where('jahr',$schuljahr+0); // erzwinge numerischen Datentyp
		$this->db->where('abschnitt <',$abschnitt+0); // erzwinge numerischen Datentyp
		
		$this->db->group_by('jahr, abschnitt'); // Access erlaubt kein DISTINCT+ORDERBY, deshalb hier GRUPPIERUNG
			
		$this->db->order_by('abschnitt','desc');
		
		$query = $this->db->get();			
		return $query->result_array();		
	}

	/* Ermittle Abschnitte des vorangegangenen Schuljahrs für die gewählte (Vorgänger-)Klasse */
	public function getAbschnitteZuletztByKlasse($klasse, $schuljahr, $abschnitt) {
		$this->db->select('jahr, abschnitt');
		$this->db->from('schuelerlernabschnittsdaten');

		$this->db->where('klasse',$klasse);
		$this->db->where('jahr',$schuljahr-1); // erzwinge numerischen Datentyp
		
		$this->db->group_by('jahr, abschnitt'); // Access erlaubt kein DISTINCT+ORDERBY, deshalb hier GRUPPIERUNG	
		$this->db->order_by('abschnitt','desc');
		
		$query = $this->db->get();			
		return $query->result_array();		
	}

	/* Ermittle Vorgängerklasse */
	public function getVorgaengerklasse($klasse) {
		$this->db->select('vklasse');
		$this->db->from('versetzung');
		$this->db->where('klasse',$klasse);
		$query = $this->db->get();			
		$row = $query->row(); 
		return $row->vklasse;		
	}


	/* ------------------------------------------------------ */
	/*  Besondere Gruppe: Kurs                                */
	/* ------------------------------------------------------ */

	/* Ermittelt alle Schüler des angegebenen Kurses */
	public function getSchuelerByKurs($id, $aktuell, $my_db) {

	 	$this->db->select($this->attribute);
		$this->db->select('schuelerlernabschnittsdaten.wiederholung');
		$this->db->select('schuelerleistungsdaten.kursart');
		$this->db->select('schuelerleistungsdaten.notenkrz');

	 	$this->db->from('schueler');
		$this->db->join('schuelerlernabschnittsdaten','schueler.id=schuelerlernabschnittsdaten.schueler_id','inner');		
		$this->db->join('schuelerleistungsdaten','schuelerleistungsdaten.abschnitt_id=schuelerlernabschnittsdaten.id','inner');				

	 	$this->db->where('geloescht','-');		
		if ($aktuell===true) { // im aktuellen Abschnitt nur Aktive und Externe anzeigen, sonst auch Ehemalige usw.
			$this->db->where_in('status',array(2,6));			
		}
	 	$this->db->where('schuelerleistungsdaten.kurs_id',$id+0); // erzwinge numerischen Datentyp		

	 	$this->db->order_by('name','asc');
	 	$this->db->order_by('vorname','asc');

	 	$query = $this->db->get();			
	 	return $query->result_array();
	}

	/* Ermittelt für die Kursüberschrift weitere Daten zum Kurs mit der angegebenen ID */
	public function getKursInfos($id) {
	 	$this->db->select('id, kurzbez, lehrerkrz, asdjahrgang, kursartallg, jahr, abschnitt');
		
	 	$this->db->from('kurse');
	 	$this->db->where('id',$id+0); // erzwinge numerischen Datentyp
		
	 	$query = $this->db->get();			
		return $query->row(); // max. die erste Zeile		
	}

	/* Hilfsmethode ermittelt den aktuellen Abschnitt */
	public function getAbschnitt() {
		$this->db->select('schuljahr, schuljahrabschnitt');
		$this->db->from('eigeneschule');

		$query = $this->db->get();					
		$row = $query->row(); 
		
		return array($row->schuljahr, $row->schuljahrabschnitt);
	}



	/* ------------------------------------------------------ */
	/*  Hilfsmethoden für diverse Fälle                       */
	/* ------------------------------------------------------ */

	/* Holt einige Infos über die Schule ein */
	public function getSchuldaten() {
	 	$this->db->select('bezeichnung1, schuljahr, schuljahrabschnitt, anzahlabschnitte, abschnittbez');
	 	$this->db->from('eigeneschule');
		
	 	$query = $this->db->get();			
		return $query->row(); // max. die erste Zeile		
	}


}

?>