<?php

class Schuelersearch_model extends CI_Model {

	// Attribute, die bei allen Anfragen projeziert werden
	private $attribute = "schueler.id, schueler.name, schueler.vorname, schueler.klasse, schueler.asdjahrgang, schueler.strasse, schueler.plz, schueler.ortabk, schueler.telefon, schueler.geburtsdatum, schueler.geschlecht, schueler.externeschulnr, schueler.aufnahmedatum, schueler.entlassdatum, schueler.status";


	public function __construct() {
		parent::__construct();
	    $this->load->database();
		
	}
	
	
	/* ------------------------------------------------------ */
	/*  Textsuche: Name, Vorname                              */
	/* ------------------------------------------------------ */

	/* Ermittelt alle aktiven Schüler mit matchendem Nachnamen */
	public function getAktiveSchuelerByNachname($query, $my_db) {
		return $this->getAktiveSchuelerByMatchingFeld($query, 'name', $my_db);
	}
	
	/* Ermittelt alle aktiven Schüler mit matchendem Vornamen */
	public function getAktiveSchuelerByVorname($query, $my_db) {
		return $this->getAktiveSchuelerByMatchingFeld($query, 'vorname', $my_db);
	}
	
	/* Hilfsmethode ermittelt alle aktiven Schüler mit matchendem Feld */
	private function getAktiveSchuelerByMatchingFeld($query, $feld, $my_db) {
		$this->db->select($this->attribute);
		$this->db->from('schueler');
		$this->db->where('geloescht','-');
		$this->db->where('status',2);
		
		$this->db->like($feld,$query);	
		
		$this->db->order_by('name','asc');
		$this->db->order_by('vorname','asc');

		$query = $this->db->get();			
		return $query->result_array();
	}
	
	
	/* ------------------------------------------------------ */
	/*  Allgemeine Suche                                      */
	/* ------------------------------------------------------ */
	
	/* Suche alle auf die Suchparameter passenden Lehrer */
	public function searchSchueler($param, $my_db) {
		
		list($schuljahr_aktuell, $abschnitt_aktuell) = $this->getAbschnitt(); // ermittle aktuellen Abschnitt

		// Projektion nach den Parametern aufbauen
		$this->db->select('schueler.id, schueler.name, schueler.vorname');

		if ($param['klasse']==='on') { $this->db->select('schueler.klasse'); }
		if ($param['lehrer']==='on') { $this->db->select('schueler.lehrer'); }
		if ($param['jahrgang']==='on') { $this->db->select('schueler.asdjahrgang'); }
		if ($param['wdh']==='on') { $this->db->select('schuelerlernabschnittsdaten.wiederholung'); }
		if ($param['geschlecht']==='on') { $this->db->select('schueler.geschlecht'); }
		if ($param['gebdatum']==='on') { $this->db->select('schueler.geburtsdatum'); }

		if ($param['aufnahme']==='on') { $this->db->select('schueler.aufnahmedatum'); }
		if ($param['abgang']==='on') { $this->db->select('schueler.entlassdatum'); }
		if ($param['uebergang']==='on') { $this->db->select('schueler.uebergangsempfehlung_jg5'); }

		if ($param['strasse']==='on') { $this->db->select('schueler.strasse'); }
		if ($param['ort']==='on') { $this->db->select('schueler.plz, schueler.ortabk'); }
		if ($param['telefon']==='on') { $this->db->select('schueler.telefon'); }
		if ($param['email']==='on') { $this->db->select('schueler.email'); }

		// Tabellen einbinden
		
		if ($param['wahlkurs']!="beliebig") {
		 	$this->db->from('schueler');
			$this->db->join('schuelerlernabschnittsdaten','schueler.id=schuelerlernabschnittsdaten.schueler_id','inner');		
			$this->db->join('schuelerleistungsdaten','schuelerleistungsdaten.abschnitt_id=schuelerlernabschnittsdaten.id','inner');				
		}
		
		else if (($param['wdh']==='on') && ($param['wahlkurs']==="beliebig")) { // Fall in oberem Fall enthalten
			$this->db->from('schueler');
			$this->db->join('schuelerlernabschnittsdaten','schueler.id=schuelerlernabschnittsdaten.schueler_id','inner'); // INNER JOIN
		}
		
		else {
			$this->db->from('schueler');			
		}
		
		// feste Bedingungen
		$this->db->where('schueler.geloescht','-');

		// Bedingungen nach Parametern
		if ($param['wdh']==='on') { // Wiederholung bezieht sich immer auf den aktuellen Abschnitt
			$this->db->where('schuelerlernabschnittsdaten.jahr',$schuljahr_aktuell+0); // erzwinge numerischen Datentyp
			$this->db->where('schuelerlernabschnittsdaten.abschnitt',$abschnitt_aktuell+0); // erzwinge numerischen Datentyp			
		}
		if ($param['wahlkurs']!="beliebig") { 
			$this->db->where('schuelerleistungsdaten.kurs_id',$param['wahlkurs']+0); // Erzwinge num. Datentyp
		}
		if ($param['wahlklasse']!="beliebig") {
			$this->db->where('schueler.klasse', $param['wahlklasse']);
		}
		if ($param['wahljahrgang']!="beliebig") {
			$this->db->where('schueler.asdjahrgang', $param['wahljahrgang']);
		}

		// Bedingung nach Status
		$stati = array();
		if ($param['aktiv']==='on') { array_push($stati, 2); }
		if ($param['abgaenger']==='on') { array_push($stati, 9); }
		if ($param['abschluss']==='on') { array_push($stati, 8); }
		if ($param['extern']==='on') { array_push($stati, 6); }
		if ($param['beurlaubt']==='on') { array_push($stati, 3); }
		if ($param['neuaufnahme']==='on') { array_push($stati, 0); }
		if ($param['warteliste']==='on') { array_push($stati, 1); }
		$this->db->where_in('schueler.status',$stati);

		// Sortierung nach Parametern
		$order = "asc";
		if ($param['absteigend']==="on") {
			$order = "desc";
		}
		if ($param['sortierung']==="klasse") {
			$this->db->order_by('schueler.klasse',$order);			
			$this->db->order_by('schueler.name','asc');
			$this->db->order_by('schueler.vorname','asc');			
		}
		else if ($param['sortierung']==="ort") {
			$this->db->order_by('schueler.ortabk',$order);						
			$this->db->order_by('schueler.strasse','asc');						
		}
		else if ($param['sortierung']==="gebdatum") {
			$this->db->order_by('schueler.geburtsdatum',$order);						
		}
		else if ($param['sortierung']==="aufnahme") {
			$this->db->order_by('schueler.aufnahmedatum',$order);						
		}
		else if ($param['sortierung']==="abgang") {
			$this->db->order_by('schueler.entlassdatum',$order);						
		}
		else { // Default: Sortierung nach Name
			$this->db->order_by('schueler.name',$order);
			$this->db->order_by('schueler.vorname','asc');						
		}

		$query = $this->db->get();			
		return $query->result_array();
		
	}


	/* Hilfsmethode ermittelt den aktuellen Abschnitt */
	public function getAbschnitt() {
		$this->db->select('schuljahr, schuljahrabschnitt');
		$this->db->from('eigeneschule');

		$query = $this->db->get();					
		$row = $query->row(); 
		
		return array($row->schuljahr, $row->schuljahrabschnitt);
	}





}

?>